package org.jaggregator.config;

import java.io.File;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.collections.SequencedHashMap;

/**
 * Configuration for JAggregator.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.6 $
 */
public class Configuration 
{
/**
 * Directory under which JAggregator finds templates etc.
 */
private File skinDirectory = new File("skins/default");

/**
 * Directory under which JAggregator stores subscription data
 * etc.
 */
private File subscriptionsDirectory = new File("subscriptions");

/**
 * Directory under which JAggregator stores generated HTML files.
 * etc.
 */
private File outputDirectory = new File("output");

/**
 * Default refresh rate for channels in milliseconds.
 */
private long refreshRate = 3L * 60L * 60L * 1000L;

/**
 * String to be included in the HTTP referer when retrieving a
 * channel. See <a
 * href="http://radio.userland.com/moreVisibleInRefererLogs">here</a>.
 */
private String webLogUrl;

/**
 * If JAggregator needs to communicate via a proxy, this variable
 * holds its name.
 */
private String proxyHost;

/**
 * Port of the proxy.
 */
private int proxyPort = -1;

private Map subscriptionListMap = new SequencedHashMap();

private Map templateMap = new SequencedHashMap();

public Configuration() 
{}

public void setSkinDirectory(File skinDirectory)
{
  this.skinDirectory = skinDirectory;
}

public File getSkinDirectory()
{
  return skinDirectory;
}

public void setSubscriptionsDirectory(File subscriptionsDirectory)
{
  this.subscriptionsDirectory = subscriptionsDirectory;
}

public File getSubscriptionsDirectory()
{
  return subscriptionsDirectory;
}

public void setOutputDirectory(File outputDirectory)
{
  this.outputDirectory = outputDirectory;
}

public File getOutputDirectory()
{
  return outputDirectory;
}

public void setRefreshRate(long refreshRate)
{
  this.refreshRate = refreshRate;
}

public void setRefreshRateInHours(int refreshRateInHourse)
{
  this.refreshRate = refreshRateInHourse * 60L * 60L * 1000L;
}

public long getRefreshRate()
{
  return refreshRate;
}

public void setWebLogUrl(String webLogUrl)
{
  this.webLogUrl = webLogUrl;
}

public String getWebLogUrl()
{
  return webLogUrl;
}

public boolean hasWebLogUrl()
{
  return (webLogUrl != null);
}

public void setProxyHost(String proxyHost)
{
  this.proxyHost = proxyHost;
}

public String getProxyHost()
{
  return proxyHost;
}

public void setProxyPort(int proxyPort)
{
  this.proxyPort = proxyPort;
}

public int getProxyPort()
{
  return proxyPort;
}

public boolean isProxySet()
{
  return ((proxyHost != null) && (proxyPort != -1));
}

public void addSubscriptionList(SubscriptionListDecl list)
{
  subscriptionListMap.put(list.getId(), list);
}

public Map getSubscriptionListMap()
{
  return Collections.unmodifiableMap(subscriptionListMap);
}

public Collection getSubscriptionLists()
{
  return Collections.unmodifiableCollection(subscriptionListMap.values());
}

public SubscriptionListDecl getSubscriptionList(String id)
{
  return (SubscriptionListDecl) subscriptionListMap.get(id);
}

public void addTemplate(TemplateDecl template)
{
  templateMap.put(template.getFileName(), template);
}

public Map getTemplateMap()
{
  return Collections.unmodifiableMap(templateMap);
}

public Collection getTemplates()
{
  return Collections.unmodifiableCollection(templateMap.values());
}
}
