package org.jaggregator.config;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import org.apache.commons.beanutils.ConvertUtils;
import org.apache.commons.beanutils.Converter;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.RuleSet;
import org.jaggregator.rss.convert.UrlConverter;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * Parser capable of parsing the jaggregator.xml file.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.11 $
 */
public class ConfigurationParser
{
private File configFile;

public ConfigurationParser(File configFile)
{
  this.configFile = configFile;
}

public Configuration parse()
  throws IOException, SAXException
{
  Digester digester = new Digester();
  digester.setNamespaceAware(false);
  ConvertUtils.register(new FileConverter(), File.class);
  ConvertUtils.register(new UrlConverter(), URL.class);
  digester.addRuleSet(new ConfigurationRuleSet());

  return (Configuration) digester.parse(
    new InputSource(configFile.toURL().toExternalForm()));
}

private class ConfigurationRuleSet
  implements RuleSet
{
public String getNamespaceURI()
{
  return null;
}

public void addRuleInstances(Digester digester)
{
  digester.addObjectCreate("jaggregator",
                           "org.jaggregator.config.Configuration");
  digester.addCallMethod("jaggregator/skin-directory",
                         "setSkinDirectory",
                         0,
                         new Class[] { File.class });
  digester.addCallMethod("jaggregator/subscriptions-directory",
                         "setSubscriptionsDirectory",
                         0,
                         new Class[] { File.class });
  digester.addCallMethod("jaggregator/output-directory",
                         "setOutputDirectory",
                         0,
                         new Class[] { File.class });
  digester.addCallMethod("jaggregator/refresh-rate",
                         "setRefreshRateInHours",
                         0,
                         new Class[] { Integer.TYPE });
  digester.addCallMethod("jaggregator/weblog-url",
                         "setWebLogUrl",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("jaggregator/proxy/host",
                         "setProxyHost",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("jaggregator/proxy/port",
                         "setProxyPort",
                         0,
                         new Class[] { Integer.TYPE });
 digester.addObjectCreate("jaggregator/subscription-list",
                          "org.jaggregator.config.SubscriptionListDecl");
 digester.addSetNext("jaggregator/subscription-list",
                     "addSubscriptionList");
 digester.addCallMethod("jaggregator/subscription-list",
                        "setId",
                        1,
                        new Class[] { String.class });
 digester.addCallParam("jaggregator/subscription-list",
                       0,
                       "id");
 digester.addObjectCreate("jaggregator/subscription-list/subscription",
                           "org.jaggregator.config.SubscriptionDecl");
 digester.addSetNext("jaggregator/subscription-list/subscription",
                     "put");
 digester.addCallMethod("jaggregator/subscription-list/subscription",
                        "setChannelUri",
                        1,
                        new Class[] { URL.class });
 digester.addCallParam("jaggregator/subscription-list/subscription",
                       0,
                       "uri");
 digester.addCallMethod("jaggregator/subscription-list/subscription/alt-name",
                        "setAltName",
                        0,
                        new Class[] { String.class });
 digester.addObjectCreate("jaggregator/template-list/template",
                           "org.jaggregator.config.TemplateDecl");
 digester.addSetNext("jaggregator/template-list/template",
                     "addTemplate");
 digester.addCallMethod("jaggregator/template-list/template",
                        "setFileName",
                        1,
                        new Class[] { String.class });
 digester.addCallParam("jaggregator/template-list/template",
                       0,
                       "file");
 digester.addCallMethod("jaggregator/template-list/template",
                        "setInvokeModeClassName",
                        1,
                        new Class[] { String.class });
 digester.addCallParam("jaggregator/template-list/template",
                       0,
                       "invokeModeClass");
 digester.addCallMethod("jaggregator/template-list/template",
                        "setInvokeMode",
                        1,
                        new Class[] { String.class });
 digester.addCallParam("jaggregator/template-list/template",
                       0,
                       "invokeMode");
 digester.addCallMethod("jaggregator/template-list/template/view",
                        "setViewClassName",
                        0);
 digester.addCallMethod(
   "jaggregator/template-list/template/subscription-list-ref",
   "addSubscriptionListRef",
   1,
   new Class[] { String.class });
 digester.addCallParam(
   "jaggregator/template-list/template/subscription-list-ref",
   0,
   "ref");
}
}

private class FileConverter
  implements Converter
{
public Object convert(Class type,
                      Object value)
{
  return new File((String) value);
}
}
}
