package org.jaggregator.generator;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Collection;
import java.util.Map;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Category;
import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.Velocity;
import org.apache.velocity.exception.ParseErrorException;
import org.apache.velocity.exception.ResourceNotFoundException;
import org.jaggregator.config.TemplateDecl;

/**
 * Invoker that applies the template once to all subscriptions in
 * all subscription lists. This creates one file that consists of
 * data from all subscriptions in all lists.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class AllListsInvoker 
 extends AbstractInvoker
{
private Category log = Category.getInstance(AllListsInvoker.class);

public void doApply(TemplateDecl templateDecl,
                    Collection subscriptionsCol,
                    Collection subscriptionListsCol,
                    Map allSubscriptionsMap,
                    View view,
                    VelocityContext context)
  throws SiteGenerationException, ResourceNotFoundException,
  ParseErrorException, IOException, Exception
{
  String templateName = templateDecl.getFileName();
  
  log.debug("apply template: " + templateName);

  if(view != null)
    {
      ((AllListsView)view).setSubscriptions(subscriptionsCol);
      view.initialize();
    }
  
  File outputFile = 
    hrefGenerator.createFileForIndex(templateDecl.getFileName());
  BufferedWriter writer = writer = new BufferedWriter(
    new OutputStreamWriter(new FileOutputStream(outputFile)));
  
  Template velTemplate = 
    Velocity.getTemplate(templateName);
  velTemplate.merge(context, writer);
  
  writer.flush();
  writer.close();

  log.debug("applied template: " + templateName);
}
}
