package org.jaggregator.rss;

import java.net.URL;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * Basic information about a channel.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.14 $
 */
public interface Channel
  extends Cloneable
{
/**
 * Return the version of the channel's RSS representation.
 */
Version getVersion();

/**
 * Set the version of the channel's RSS
 * representation. <strong>Please note that setting the version
 * value to a different value does not convert the channel to
 * that version.</strong>. This method should only be used for
 * restoring a channel from external storage.
 */
void setVersion(Version version);

/**
 * Return the name of the channel.
 */
String getTitle();

/**
 * Set the name of the channel.
 */
void setTitle(String title);

/**
 * Test whether the channel has a title.
 */
boolean hasTitle();

/**
 * Return the URL pointing to the website named in the &lt;title&gt;.
 */
URL getLink();

/**
 * Return the URL pointing to the website named in the &lt;title&gt;.
 */
void setLink(URL link);

/**
 * Test whether the channel has a link.
 */
boolean hasLink();

/**
 * Return the phrase that describes the channel (the channel's
 * positioning statement).
 */
String getDescription();

/**
 * Set the phrase that describes the channel (the channel's
 * positioning statement).
 */
void setDescription(String description);

/**
 * Test whether the channel has a description.
 */
boolean hasDescription();

/**
 * Return the description of the image that represents the channel.
 */
ChannelImage getImage();

/**
 * Set the description of the image that represents the channel.
 */
void setImage(ChannelImage image);

/**
 * Test whether the channel has a image.
 */
boolean hasImage();

/**
 * Return the description of the textarea that the channel may contain.
 */
TextInput getTextInput();

/**
 * Set the description of the textarea that the channel may contain.
 */
void setTextInput(TextInput textInput);

/**
 * Test whether the channel has a textinput.
 */
boolean hasTextInput();

/**
 * Return the list of items. A channel may contain any number of
 * &lt;item&gt;s, each of which links to a story, with an optional
 * description.
 */
List getItems();

/**
 * Set the list of items. A channel may contain any number of
 * &lt;item&gt;s, each of which links to a story, with an optional
 * description.
 */
void setItems(List items);

/**
 * Add an item to the list of items. A channel may contain any
 * number of &lt;item&gt;s, each of which links to a story, with
 * an optional description.
 */
boolean addItem(Item item);

/**
 * Test whether the channel has items.
 */
boolean hasItems();

/**
 * Indicates whether some other channel is "equal to" this
 * one. The same rules apply as for equals.
 *
 * @param o the <code>Channel</code> with which to compare. 
 * @return true if this object is the same as the obj argument;
 * false otherwise
 */
boolean channelLevelEquals(Channel o);

/**
 * Return a shallow copy of this instance.
 *
 * @return the clone
 * @exception CloneNotSupportedException if an error occurs
 */
Object clone()
  throws CloneNotSupportedException;
}
