package org.jaggregator.rss;

import java.net.URL;

/**
 * A channel may contain any number of <item>s. An item may
 * represent a "story" -- much like a story in a newspaper or
 * magazine; if so its description is a synopsis of the story,
 * and the link points to the full story. An item may also be
 * complete in itself, if so, the description contains the text
 * (entity-encoded HTML is allowed), and the link and title may
 * be omitted. All elements of an item are optional, however at
 * least one of title or description must be present.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.10 $
 */
public interface Item 
{
/**
 * Get the channel that this item belongs to
 *
 * @return a <code>Channel</code> value
 */
Channel getChannel();

/**
 * Set the channel that this item belongs to
 *
 * @return a <code>Channel</code> value
 */
void setChannel(Channel channel);

/**
 * Returns the item's title.
 */
String getTitle();

/**
 * Sets the item's title. May not be null.
 */
void setTitle(String title);

/**
 * Tests whether this object has a title.
 */
boolean hasTitle();

/**
 * Returns the item's link.
 */
URL getLink();

/**
 * Sets the item's link. May not be null.
 */
void setLink(URL link);

/**
 * Tests whether this object has a link.
 */
boolean hasLink();

/**
 * Returns the item's description.
 */
String getDescription();

/**
 * Sets the item's description. May not be null.
 */
void setDescription(String description);

/**
 * Tests whether this object has a description.
 */
boolean hasDescription();

/**
 * Return an ID for this item. It is important that the
 * calculation has to be deterministic, which means, that for
 * instance the standard hashCode(), which takes the memory
 * address into account, is not a suitable ID generator.
 */
int calculateUniqueId();
}
