package org.jaggregator.rss.common;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.jaggregator.rss.Extensible;
import org.jaggregator.rss.Module;

/**
 * Utilityclass that helps implementing extensions.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.4 $
 */
public class ExtensionSupport
  implements Extensible
{
private Map extensionMap;

public ExtensionSupport()
{
  this.extensionMap = new HashMap();
}

public Collection getModules()
{
  return extensionMap.values();
}

public Module getModule(String namespace)
{
  return (Module) extensionMap.get(namespace);
}

public void addModule(Module module)
{
  extensionMap.put(module.getNamespace(), module);
}

public boolean hasModule(String namespace)
{
  return extensionMap.containsKey(namespace);
}

/**
 * Two <code>ExtensionSupport</code> instances are equals, iff
 * they contain modules for the same set of namespaces.
 *
 * @param o the object with which to compare
 * @return true if this object is the same as the obj argument;
 * false otherwise
 */
public boolean equals(Object o)
{
  if(this == o)
    return true;

  if(o == null)
    return false;
  
  if(this.getClass() != o.getClass())
    return false;
  
  ExtensionSupport rhs = (ExtensionSupport) o;
  
  return new EqualsBuilder()
    .append(extensionMap.keySet(), rhs.extensionMap.keySet())
    .isEquals();
}

public int hashCode()
{
  return new HashCodeBuilder(52919, 157)
    .append(extensionMap.keySet())
    .toHashCode();
}
}
