package org.jaggregator.rss.common;

import java.net.URL;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.util.UrlUtils;

/**
 * Canonical implementation of the <code>Item</code> interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.7 $
 */
public class ItemImpl
  implements Item 
{
private Channel channel;
private String title;
private URL link;
private String description;

public ItemImpl() 
{}

public ItemImpl(String title,
                URL link,
                String description)
{
  this.title = title;
  this.link = link;
  this.description = description;
}

public Channel getChannel()
{
  return channel;
}

public void setChannel(Channel channel)
{
  this.channel = channel;
}

public String getTitle() 
{
  return title;
}

public void setTitle(String title)
{
  this.title = title;
}

public boolean hasTitle()
{
  return (title != null);
}

public URL getLink() 
{
  return link;
}

public void setLink(URL link)
{
  this.link = link;
}

public boolean hasLink()
{
  return (link != null);
}

public String getDescription() 
{
  return description;
}

public void setDescription(String description)
{
  this.description = description;
}

public boolean hasDescription()
{
  return (description != null);
}

public String toString()
{
  return new ToStringBuilder(this)
    .append("title", title)
    .append("link", 
            (link == null) ? null : link.toExternalForm())
    .append("description", description)
    .toString();
}

public boolean equals(Object o) 
{
  if(!(o instanceof ItemImpl))
    return false;

  ItemImpl rhs = (ItemImpl) o;
  return new EqualsBuilder()
    .append(title, rhs.title)
    .append(UrlUtils.toString(link), UrlUtils.toString(rhs.link))
    .append(description, rhs.description)
    .isEquals();
}

public int hashCode() 
{
  return new HashCodeBuilder(17, 37).
    append(title).
    append(UrlUtils.toString(link)).
    append(description).
    toHashCode();
}

public int calculateUniqueId()
{
  return hashCode();
}
}
