package org.jaggregator.rss.digester;

import org.apache.commons.digester.Rule;
import org.jaggregator.rss.Extensible;
import org.jaggregator.rss.Module;
import org.xml.sax.Attributes;

/**
 * This rule creates a new object in its
 * <code>begin</code>-Method but does not push it on the
 * stack. In order to push it on the stack, use a
 * <code>PushModuleRule</code>-Object.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.1 $
 */
public class ModuleInitializationRule
  extends Rule 
{
private String className;
private Module module;

public ModuleInitializationRule(String className) 
{
  this.className = className;
}

public ModuleInitializationRule(Class clazz)
{
  this(clazz.getName());
}

public Module getModule()
{
  return module;
}

public void begin(Attributes attributes)
  throws Exception
{
  if (digester.getLogger().isDebugEnabled())
    {
      digester.getLogger().debug(
        "[ModuleInitializationRule]{" + digester.getMatch() +
        "}New " + className);
    }
  
  // Instantiate the new object and push it on the context stack
  Class clazz = digester.getClassLoader().loadClass(className);
  module = (Module) clazz.newInstance();
}

public void end()
  throws Exception
{
  digester.getLogger().debug("[ModuleInitializationRule]{" + 
                             digester.getMatch() +
                             "} End");
  
  if(module == digester.peek())
    {
      Object top = digester.pop();
      if (digester.getLogger().isDebugEnabled()) {
        digester.getLogger().debug("[ModuleInitializationRule]{" + 
                           digester.getMatch() +
                           "} Pop " + top.getClass().getName());
      }
    }
  
  Extensible extensible = (Extensible) digester.peek();
  module.addTo(extensible);
}

public String toString()
{
  StringBuffer sb = new StringBuffer("ModuleInitializationRule[");
  sb.append("className=");
  sb.append(className);
  sb.append("]");
  
  return (sb.toString());
}

}
