package org.jaggregator.rss.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;
import java.io.Writer;
import org.apache.ecs.Filter;
import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelExporter;
import org.jaggregator.rss.Version;

/**
 * Utilityclass for implementing <code>ChannelExporter</code>s.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.12 $
 */
public abstract class AbstractExporter
  implements ChannelExporter
{
protected Version version;
protected FragmentExporterSupport exporterSupport;

static 
{
  //Using this trick, we modify the filter for all XML elements
  //as this implicitely changes the default filter.
  XML xml = new XML("xxx");
  Filter filter = xml.getFilter();

  filter.addAttribute("\"", "&quot;");
  filter.addAttribute("'", "&apos;");
  filter.addAttribute("&", "&amp;");
  filter.addAttribute("<", "&lt;");
  filter.addAttribute(">", "&gt;");
}

public AbstractExporter(Version version)
{
  this.version = version;
  this.exporterSupport = new FragmentExporterSupport();
}

public boolean canWrite(Version version)
{
  return this.version.equals(version);
}

protected void runExporters(Object key, 
                            Channel channel, 
                            XML parent,
                            XML root,
                            Object param)
{
  exporterSupport.runExporters(key, channel, parent, root, param);
}

protected void registerExporter(Object key, FragmentExporter exporter)
{
  exporterSupport.registerExporter(key, exporter);
}

protected void deregisterExporter(Object key, FragmentExporter exporter)
{
  exporterSupport.deregisterExporter(key, exporter);
}
}
