package org.jaggregator.rss.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.Iterator;
import org.apache.ecs.xml.XML;
import org.apache.ecs.xml.XMLDocument;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Rss;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.util.FileUtils;

/**
 * Exporter capable of exporting a <code>Channel</code> to RSS
 * 0.90.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class ExporterImpl_0_90
  extends AbstractExporter
{
private PrintWriter writer;
private boolean withFile;

public ExporterImpl_0_90(File file)
  throws FileNotFoundException
{
  this(Version.VERSION_0_90, file);
}

protected ExporterImpl_0_90(Version version, File file)
  throws FileNotFoundException
{
  super(version);
  
  this.writer = new PrintWriter(FileUtils.createWriter(file));
  this.withFile = true;
  
  registerFragmentExporters();
}

public ExporterImpl_0_90(OutputStream stream)
{
  this(Version.VERSION_0_90, stream);
}

protected ExporterImpl_0_90(Version version, OutputStream ostream)
{
  super(version);

  this.writer = new PrintWriter(ostream);

  registerFragmentExporters();
}

protected void registerFragmentExporters()
{
  registerExporter(Rss.class, new ChannelFragmentExporterImpl_0_90());
  registerExporter(Rss.class, new ImageFragmentExporterImpl());
  registerExporter(Rss.class, new ItemFragmentExporterImpl());
  registerExporter(Rss.class, new TextInputFragmentExporterImpl());
}

public void export(Channel channel)
  throws IOException
{
  XMLDocument document = new XMLDocument(1.0);
  document.setCodeset("UTF-8");

  XML rdfXML = new XML("rdf:RDF");
  rdfXML.addXMLAttribute("xmlns:rdf", 
                         "http://www.w3.org/1999/02/22-rdf-syntax-ns#");
  rdfXML.addXMLAttribute("xmlns", 
                         "http://my.netscape.com/rdf/simple/0.9/");
  
  document.addElement(rdfXML);

  runExporters(Rss.class, channel, rdfXML, rdfXML, null);
  
  document.output(writer);
  writer.flush();

  if(withFile)
    writer.close();
}

private class ChannelFragmentExporterImpl_0_90
  extends ChannelFragmentExporterImpl
{
public void export(Channel channel, XML rdfXML, XML root, Object param)
{
  XML channelXML = new XML("channel");
  rdfXML.addElement(channelXML);
  
  super.export(channel, channelXML, root, param);
}
}
}

