package org.jaggregator.rss.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Writer;
import java.util.Iterator;
import org.apache.ecs.xml.XML;
import org.apache.ecs.xml.XMLDocument;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Rss;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.rss_1_00.ChannelImage_1_00;
import org.jaggregator.rss.rss_1_00.Channel_1_00;
import org.jaggregator.rss.rss_1_00.Item_1_00;
import org.jaggregator.rss.rss_1_00.TextInput_1_00;
import org.jaggregator.rss.util.FileUtils;

/**
 * Exporter capable of exporting a <code>Channel</code> to RSS
 * 1.0.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.10 $
 */
public class ExporterImpl_1_00
  extends AbstractExporter
{
private PrintWriter writer;
private boolean withFile;

public ExporterImpl_1_00(File file)
  throws FileNotFoundException
{
  this(Version.VERSION_1_00, file);
}

protected ExporterImpl_1_00(Version version, File file)
  throws FileNotFoundException
{
  super(version);
  
  this.writer = new PrintWriter(FileUtils.createWriter(file));
  this.withFile = true;
  
  registerFragmentExporters();
}

public ExporterImpl_1_00(OutputStream stream)
{
  this(Version.VERSION_1_00, stream);
}

protected ExporterImpl_1_00(Version version, OutputStream ostream)
{
  super(version);

  this.writer = new PrintWriter(ostream);

  registerFragmentExporters();
}

protected void registerFragmentExporters()
{
  registerExporter(Rss.class, new ChannelFragmentExporterImpl_1_00());
  registerExporter(Rss.class, new ImageFragmentExporterImpl_1_00());
  registerExporter(Rss.class, new ItemFragmentExporterImpl_1_00());
  registerExporter(Rss.class, new TextInputFragmentExporterImpl_1_00());
}

public void export(Channel channel)
  throws IOException
{
  XMLDocument document = new XMLDocument(1.0);
  document.setCodeset("UTF-8");

  XML rdfXML = new XML("rdf:RDF");
  rdfXML.addXMLAttribute("xmlns:rdf", 
                         "http://www.w3.org/1999/02/22-rdf-syntax-ns#");
  rdfXML.addXMLAttribute("xmlns", 
                         "http://purl.org/rss/1.0/");
  
  document.addElement(rdfXML);

  runExporters(Rss.class, channel, rdfXML, rdfXML, null);
  
  document.output(writer);
  writer.flush();

  if(withFile)
    writer.close();
}

private class ChannelFragmentExporterImpl_1_00
  extends ChannelFragmentExporterImpl
{
public void export(Channel channel, XML rdfXML, XML root, Object param)
{
  Channel_1_00 channel100 = (Channel_1_00) channel;
  XML channelXML = new XML("channel");
  rdfXML.addElement(channelXML);
  
  super.export(channel, channelXML, root, param);
  
  channelXML.addXMLAttribute("rdf:about", channel100.getAbout());

  if(channel.hasImage())
    {
      ChannelImage_1_00 image = (ChannelImage_1_00) channel.getImage();
      
      channelXML.addElement(
        new XML("image")
        .addXMLAttribute("rdf:resource", image.getAbout()));
    }

  if(channel.hasItems())
    {
      Iterator iter = channel.getItems().iterator();
      XML itemsXML = new XML("items");
      channelXML.addElement(itemsXML);
      XML rdfSeqXML = new XML("rdf:Seq");
      itemsXML.addElement(rdfSeqXML);
      
      while(iter.hasNext())
        {
          Item_1_00 item = (Item_1_00) iter.next();
      
          XML itemXML = new XML("rdf:li");
          itemXML.addXMLAttribute("resource",
                                  item.getAbout());
          rdfSeqXML.addElement(itemXML);
        }
    }

  if(channel.hasTextInput())
    {
      TextInput_1_00 textInput = (TextInput_1_00) channel.getTextInput();
      
      XML textInputXML = new XML("textinput");
      textInputXML.addXMLAttribute("rdf:resource",
                                   textInput.getAbout());
      
      channelXML.addElement(textInputXML);
    }
}
}
}
