package org.jaggregator.rss.exporter;

import java.util.Collection;
import java.util.Iterator;
import org.apache.commons.collections.IteratorUtils;
import org.apache.commons.collections.MultiHashMap;
import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;

/**
 * Utitliy class, which helps implementing
 * <code>(Fragement)Exporter</code>, that allow registering of
 * other exporters.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.7 $
 */
public class FragmentExporterSupport
{
private MultiHashMap exporterMap;

public FragmentExporterSupport()
{
  this.exporterMap = new MultiHashMap();
}

protected void runExporters(Object key, 
                            Channel channel, 
                            XML parent,
                            XML root,
                            Object param)
{
  Collection exporters = (Collection) exporterMap.get(key);

  if(exporters == null)
    return;
  
  Iterator iter = exporters.iterator();
  while(iter.hasNext())
    {
      FragmentExporter exporter = (FragmentExporter) iter.next();
      exporter.export(channel, parent, root, param);
    }
}

protected void registerExporter(Object key, FragmentExporter exporter)
{
  exporterMap.put(key, exporter);
}

protected void deregisterExporter(Object key, FragmentExporter exporter)
{
  exporterMap.remove(key, exporter);
}

protected Iterator exporterIterator()
{
  return exporterMap.values().iterator();
}
}
