package org.jaggregator.rss.exporter;

import java.util.Iterator;
import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.exporter.FragmentExporter;

/**
 * Exports <code>title, link, description</code> of an
 * <code>Item</code>.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class ItemFragmentExporterImpl
  extends AbstractFragmentExporter
{
public ItemFragmentExporterImpl()
{
  registerExporter(Item.class,
                   new BasicItemFragmentExporterImpl());
}

public void export(Channel channel,
                   XML parent,
                   XML root,
                   Object param)
{
  if(channel.hasItems() == false)
    return;
  
  Iterator iter = channel.getItems().iterator();
  
  while(iter.hasNext())
    {
      Item item = (Item) iter.next();
      
      XML itemXML = new XML("item");

      runExporters(Item.class,
                   channel,
                   itemXML,
                   root,
                   item);
      
      parent.addElement(itemXML);
    }
}

/**
 * Does the actual export of <code>title, link,
 * description</code> of an <code>Item</code>
 */
private class BasicItemFragmentExporterImpl 
  implements FragmentExporter
{
public void export(Channel channel, XML parent, XML root, Object param)
{
  Item item = (Item) param;
  
  if(item.hasTitle())
    parent.addElement(new XML("title")
                      .addElement(item.getTitle()));
  if(item.hasLink())
    parent.addElement(new XML("link")
                      .addElement(item.getLink().toString()));
  if(item.hasDescription())
    parent.addElement(new XML("description")
                      .addElement(item.getDescription()));
}
}
}
