package org.jaggregator.rss.exporter;

import java.text.DateFormat;
import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Guid;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.modules.ContentModuleFragmentExporter;
import org.jaggregator.rss.rss_2_00.Item_2_00;

/**
 * Exports <code>author, comments, guid, pubDate</code> of an
 * <code>Item_2_00</code>. Additionally, it supports the Module
 * <code>content:encoded</code>.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class ItemFragmentExporterImpl_2_00
  extends ItemFragmentExporterImpl_0_92
{
private DateFormat format;

public ItemFragmentExporterImpl_2_00()
{
  format = (DateFormat) Commons.DATE_FORMAT.clone();

  registerExporter(Item.class,
                   new BasicItemFragmentExporterImpl_2_00());
  registerExporter(Item.class,
                   new GuidFragmentExporterImpl_2_00());
  registerExporter(Item.class,
                   new ContentModuleFragmentExporter());
}

/**
 * Does the actual export of <code>author, comments,
 * pubDate</code> of an <code>Item_2_00</code>
 */
private class BasicItemFragmentExporterImpl_2_00
  implements FragmentExporter
{
public void export(Channel channel, XML parent, XML root, Object param)
{
  Item_2_00 item = (Item_2_00) param;
  
  if(item.hasAuthor())
    parent.addElement(new XML("author")
                      .addElement(item.getAuthor()));
  if(item.hasComments())
    parent.addElement(new XML("comments")
                      .addElement(item.getComments().toString()));
  if(item.hasPubDate())
    parent.addElement(new XML("pubDate")
                      .addElement(format.format(item.getPubDate())));
}
}

/**
 * Does the actual export of <code>guid</code> of an
 * <code>Item_2_00</code>
 */
private class GuidFragmentExporterImpl_2_00
  implements FragmentExporter
{
public void export(Channel channel, XML parent, XML root, Object param)
{
  Item_2_00 item = (Item_2_00) param;
  
  if(item.hasGuid())
    {
      Guid guid = item.getGuid();
      
      XML guidXML = 
        new XML("guid");
      guidXML.addElement(guid.getGuid());

      //We have to export isPermaLink only if it is false,
      //because it is considered true, when absent.
      if(guid.isPermaLink() == false)
        guidXML.addXMLAttribute("isPermaLink", 
                                String.valueOf(guid.isPermaLink()));
        
      parent.addElement(guidXML);
    }
}
}
}
