package org.jaggregator.rss.modules;

import java.net.URL;
import org.jaggregator.rss.Module;

/**
 * A RSS module that adds elements at the <channel> level that
 * are common to weblogs.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public interface BlogChannelModule
  extends Module
{
/**
 * Get the URL of an OPML file containing the blogroll for the
 * site.
 */
URL getBlogRoll();

/**
 * Set the URL of an OPML file containing the blogroll for the
 * site.
 */
void setBlogRoll(URL blogRollUrl);

/**
 * Test whether this instance has blog roll.
 */
boolean hasBlogRoll();

/**
 * Get the URL of an OPML file containing the author's RSS
 * subscriptions.
 */
URL getSubscriptions();

/**
 * Set the URL of an OPML file containing the author's RSS
 * subscriptions.
 */
void setSubscriptions(URL subscriptionsUrl);

/**
 * Test whether this instance has subscriptions.
 */
boolean hasSubscriptions();

/**
 * Get the URL of a weblog that the author of the weblog is
 * promoting per Mark Pilgrim's description {@link
 * http://diveintomark.org/archives/2002/09/17.html#blink_and_youll_miss_it}.
 */
URL getBlink();

/**
 * Set the URL of a weblog that the author of the weblog is
 * promoting per Mark Pilgrim's description {@link
 * http://diveintomark.org/archives/2002/09/17.html#blink_and_youll_miss_it}.
 */
void setBlink(URL blinkUrl);

/**
 * Test whether this instance has a blink.
 */
boolean hasBlink();

/**
 * Get the URL of a changes.xml file. When the feed that contains
 * this element updates, it pings a server that updates this
 * file. The presence of this element says to aggregators that
 * they only have to read the changes file to see if this feed
 * has updated. If several feeds point to the same changes file,
 * the aggregator has to do less polling, resulting in better use
 * of server bandwidth, and the Internet as a whole; and
 * resulting in faster scans. Everyone wins. For more technical
 * information, see the howto {@link
 * http://www.xmlrpc.com/weblogsComForRss} on the XML-RPC site.
 */
URL getChanges();

/**
 * Set the URL of a changes.xml file. When the feed that contains
 * this element updates, it pings a server that updates this
 * file. The presence of this element says to aggregators that
 * they only have to read the changes file to see if this feed
 * has updated. If several feeds point to the same changes file,
 * the aggregator has to do less polling, resulting in better use
 * of server bandwidth, and the Internet as a whole; and
 * resulting in faster scans. Everyone wins. For more technical
 * information, see the howto {@link
 * http://www.xmlrpc.com/weblogsComForRss} on the XML-RPC site.
 */
void setChanges(URL changesUrl);

/**
 * Test whether this instance has a changes file.
 */
boolean hasChanges();
}
