package org.jaggregator.rss.modules;

import java.net.URL;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jaggregator.rss.Extensible;
import org.jaggregator.rss.common.AbstractModule;
import org.jaggregator.rss.digester.Initializable;
import org.jaggregator.rss.util.UrlUtils;

/**
 * Canonical implementation of the <code>BlogChannelModule</code>
 * interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.10 $
 */
public class BlogChannelModuleImpl_2_00
  extends AbstractModule
  implements BlogChannelModule, Initializable
{
private URL blogRollUrl;
private URL subscriptionsUrl;
private URL blinkUrl;
private URL changesUrl;

public BlogChannelModuleImpl_2_00()
{
  super(BlogChannelModuleRuleSet_2_00.NAMESPACE);
}

public boolean isInitialized()
{
  return
    (blogRollUrl != null) ||
    (subscriptionsUrl != null) ||
    (blinkUrl != null) ||
    (changesUrl != null);
}

public URL getBlogRoll()
{
  return blogRollUrl;
}

public void setBlogRoll(URL blogRollUrl)
{
  this.blogRollUrl = blogRollUrl;
}

public boolean hasBlogRoll()
{
  return (blogRollUrl != null);
}

public URL getSubscriptions()
{
  return subscriptionsUrl;
}

public void setSubscriptions(URL subscriptionsUrl)
{
  this.subscriptionsUrl = subscriptionsUrl;
}

public boolean hasSubscriptions()
{
  return subscriptionsUrl != null;
}

public URL getBlink()
{
  return blinkUrl;
}

public void setBlink(URL blinkUrl)
{
  this.blinkUrl = blinkUrl;
}

public boolean hasBlink()
{
  return (blinkUrl != null);
}

public URL getChanges()
{
  return changesUrl;
}

public void setChanges(URL changesUrl)
{
  this.changesUrl = changesUrl;
}

public boolean hasChanges()
{
  return (changesUrl != null);
}

public void addTo(Extensible extensible)
{
  if(isInitialized())
    extensible.addModule(this);
}

public boolean equals(Object o)
{
  if(this == o)
    return true;

  if(o == null)
    return false;
  
  if(this.getClass() != o.getClass())
    return false;
  
  BlogChannelModuleImpl_2_00 rhs = (BlogChannelModuleImpl_2_00) o;
  
  return new EqualsBuilder()
    .append(UrlUtils.toString(blogRollUrl), 
            UrlUtils.toString(rhs.blogRollUrl))
    .append(UrlUtils.toString(subscriptionsUrl),
            UrlUtils.toString(rhs.subscriptionsUrl))
    .append(UrlUtils.toString(blinkUrl),
            UrlUtils.toString(rhs.blinkUrl))
    .append(UrlUtils.toString(changesUrl),
            UrlUtils.toString(rhs.changesUrl))
    .isEquals();
}

public int hashCode()
{
  return new HashCodeBuilder(66373, 109)
    .append(UrlUtils.toString(blogRollUrl))
    .append(UrlUtils.toString(subscriptionsUrl))
    .append(UrlUtils.toString(blinkUrl))
    .append(UrlUtils.toString(changesUrl))
    .toHashCode();
}

public String toString()
{
  return new ToStringBuilder(this)
    .append("blogRoll", blogRollUrl)
    .append("subscriptions", subscriptionsUrl)
    .append("blink", blinkUrl)
    .append("changes", changesUrl)
    .toString();
}
}
