package org.jaggregator.rss.rss_0_91;

import java.net.URL;
import java.util.Date;
import java.util.List;
import java.util.Set;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.SkipDay;

/**
 * Enhancements for RSS 0.91.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.3 $
 */
public interface Channel_0_91
  extends Channel
{
/**
 * Return the language the channel is written in.
 */
String getLanguage();

/**
 * Set the language the channel is written in. For a list of
 * allowable values, please see {@link
 * http://backend.userland.com/stories/storyReader$16}.
 */
void setLanguage(String language);

/**
 * Tests whether this instance has a language.
 */
boolean hasLanguage();

/**
 * Return copyright notice for content in the channel.
 */
String getCopyright();

/**
 * Set copyright notice for content in the channel.
 */
void setCopyright(String copyright);

/**
 * Tests whether this instance has a copyright.
 */
boolean hasCopyright();

/**
 * Return the email address of the managing editor of the
 * channel, the person to contact for editorial inquiries.
 */
String getManagingEditor();

/**
 * Set the email address of the managing editor of the
 * channel, the person to contact for editorial inquiries.
 */
void setManagingEditor(String managingEditor);

/**
 * Tests whether this instance has a managing editor.
 */
boolean hasManagingEditor();

/**
 * Return the email address of the webmaster for the channel, the person
 * to contact if there are technical problems.
 */
String getWebmaster();

/**
 * Return the email address of the webmaster for the channel, the person
 * to contact if there are technical problems.
 */
void setWebmaster(String webmaster);

/**
 * Tests whether this instance has a webmaster.
 */
boolean hasWebmaster();

/**
 * Return the PICS rating for the channel.
 */
String getRating();

/**
 * Set the PICS rating for the channel.
 */
void setRating(String rating);

/**
 * Tests whether this instance has a rating.
 */
boolean hasRating();

/**
 * Return a URL that points to the documentation for the format used
 * in the RSS file.
 */
URL getDocs();

/**
 * Set a URL that points to the documentation for the format used
 * in the RSS file.
 */
void setDocs(URL url);

/**
 * Tests whether this instance has a url to docs.
 */
boolean hasDocs();

/**
 * Return the publication date for the content in the
 * channel. For example, the New York Times publishes on a daily
 * basis, the publication date flips once every 24 hours. That's
 * when the pubDate of the channel changes.
 */
Date getPubDate();

/**
 * Set the publication date for the content in the channel. For
 * example, the New York Times publishes on a daily basis, the
 * publication date flips once every 24 hours. That's when the
 * pubDate of the channel changes. All date-times in RSS conform
 * to the Date and Time Specification of RFC 822.
 */
void setPubDate(Date date);

/**
 * Tests whether this instance has a publication date.
 */
boolean hasPubDate();

/**
 * Return the date-time the last time the content of the channel changed.
 */
Date getLastBuildDate();

/**
 * Set the date-time the last time the content of the channel changed.
 */
void setLastBuildDate(Date buildDate);

/**
 * Tests whether this instance has a build date.
 */
boolean hasLastBuildDate();

/**
 * Return the list of days to skip when accessing the
 * channel. The list has at-most 7 items. Aggregators may not
 * read the channel during hours listed in the skipDays
 * element. (Most aggregators seem to ignore this element.)
 *
 * @return a <code>Set</code> value
 */
Set getSkipDays();

/**
 * Set the list of days to skip when accessing the
 * channel. The list has at-most 7 items. Aggregators may not
 * read the channel during hours listed in the skipDays
 * element. (Most aggregators seem to ignore this element.)
 */
void setSkipDays(Set skipDays);

/**
 * Add a days to skip when accessing the channel to the list. The
 * list has at-most 7 items. Aggregators may not read the channel
 * during hours listed in the skipDays element. (Most aggregators
 * seem to ignore this element.)
 */
boolean addSkipDay(SkipDay skipDay);

/**
 * Tests whether this instance has skip days.
 */
boolean hasSkipDays();

/**
 * Return the List of hours to skip when accessing the
 * channel. The list contains up to 24 items whose value is a
 * number between 1 and 24, representing a time in GMT, when
 * aggregators, if they support the feature, may not read the
 * channel on days listed in the skipHours element. (Most
 * aggregators seem to ignore this element.)
 */
Set getSkipHours();

/**
 * Set the List of hours to skip when accessing the
 * channel. The list contains up to 24 items whose value is a
 * number between 1 and 24, representing a time in GMT, when
 * aggregators, if they support the feature, may not read the
 * channel on days listed in the skipHours element. (Most
 * aggregators seem to ignore this element.)
 */
void setSkipHours(Set skipHours);

/**
 * Add an hour to skip when accessing the channel to the
 * list. The list contains up to 24 items whose value is a number
 * between 1 and 24, representing a time in GMT, when
 * aggregators, if they support the feature, may not read the
 * channel on days listed in the skipHours element. (Most
 * aggregators seem to ignore this element.)
 */
boolean addSkipHour(int skipHour);

/**
 * Tests whether this instance has skip hour.
 */
boolean hasSkipHours();
}
