package org.jaggregator.rss.rss_0_91;

import java.net.URL;
import java.util.Date;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.ObjectCreationFactory;
import org.apache.commons.digester.RuleSet;
import org.jaggregator.rss.SkipDay;
import org.jaggregator.rss.Version;

/**
 * RuleSet for setting up a digester for RSS 0.91.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.7 $
 */
public class RuleSet_0_91
  implements RuleSet
{
public RuleSet_0_91()
{}

/**
 * As RSS 0.91 cannot contain namespaces, this method returns
 * <code>null</code>.
 */
public String getNamespaceURI()
{
  return null;
}

public void addRuleInstances(Digester digester)
{
  digester.addObjectCreate("rss", "org.jaggregator.rss.Rss");
  digester.addCallMethod("rss", 
                         "setVersion", 
                         1, 
                         new Class[] { Version.class });
  digester.addCallParam("rss",
                        0,
                        "version");
  digester.addFactoryCreate("rss/channel", getChannelFactory());
  digester.addSetNext("rss/channel", "setChannel");
  digester.addCallMethod("rss/channel/title", "setTitle", 0);
  digester.addCallMethod("rss/channel/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/description", "setDescription", 0);
  digester.addCallMethod("rss/channel/language", "setLanguage", 0);
  digester.addCallMethod("rss/channel/copyright", "setCopyright", 0);
  digester.addCallMethod("rss/channel/managingEditor", "setManagingEditor", 0);
  digester.addCallMethod("rss/channel/webMaster", "setWebmaster", 0);
  digester.addCallMethod("rss/channel/rating", "setRating", 0);
  digester.addFactoryCreate("rss/channel/image", 
                            getChannelImageFactory());
  digester.addSetNext("rss/channel/image", "setImage");
  digester.addCallMethod("rss/channel/image/title", "setTitle", 0);
  digester.addCallMethod("rss/channel/image/url", 
                         "setUrl", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/image/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/image/width", 
                         "setWidth", 
                         0,
                         new Class[] { Integer.TYPE });
  digester.addCallMethod("rss/channel/image/height", 
                         "setHeight", 
                         0,
                         new Class[] { Integer.TYPE });
  digester.addCallMethod("rss/channel/image/description", "setDescription", 0);
  digester.addFactoryCreate("rss/channel/textinput", 
                            getTextInputFactory());
  digester.addSetNext("rss/channel/textinput", "setTextInput");
  digester.addCallMethod("rss/channel/textinput/title", "setTitle", 0);
  digester.addCallMethod("rss/channel/textinput/description", 
                         "setDescription", 0);
  digester.addCallMethod("rss/channel/textinput/name", "setName", 0);
  digester.addCallMethod("rss/channel/textinput/link",
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/docs",
                         "setDocs", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/pubDate",
                         "setPubDate", 
                         0,
                         new Class[] { Date.class });
  digester.addCallMethod("rss/channel/lastBuildDate",
                         "setLastBuildDate", 
                         0,
                         new Class[] { Date.class });
  digester.addCallMethod("rss/channel/skipDays/day",
                         "addSkipDay", 
                         0,
                         new Class[] { SkipDay.class });
  digester.addCallMethod("rss/channel/skipHours/hour",
                         "addSkipHour", 
                         0,
                         new Class[] { Integer.TYPE });
  digester.addFactoryCreate("rss/channel/item", 
                            getItemFactory());
  digester.addSetNext("rss/channel/item", "addItem");
  digester.addSetTop("rss/channel/item", "setChannel");
  digester.addCallMethod("rss/channel/item/title",
												 "setTitle", 0);
  digester.addCallMethod("rss/channel/item/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("rss/channel/item/description", 
												 "setDescription", 0);
}

protected ObjectCreationFactory getChannelFactory()
{
  return new ChannelFactory_0_91();
}

protected ObjectCreationFactory getChannelImageFactory()
{
  return new ChannelImageFactory_0_91();
}

protected ObjectCreationFactory getTextInputFactory()
{
  return new TextInputFactory_0_91();
}

protected ObjectCreationFactory getItemFactory()
{
  return new ItemFactory_0_91();
}
}
