package org.jaggregator.rss.rss_0_92;

import java.net.URL;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.ObjectCreationFactory;
import org.apache.commons.digester.RuleSet;
import org.jaggregator.rss.CloudProtocol;
import org.jaggregator.rss.rss_0_91.RuleSet_0_91;

/**
 * RuleSet for setting up a digester for RSS 0.92.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.4 $
 */
public class RuleSet_0_92
  extends RuleSet_0_91
{
public RuleSet_0_92()
{}

/**
 * As RSS 0.92 cannot contain namespaces, this method returns
 * <code>null</code>.
 */
public String getNamespaceURI()
{
  return null;
}

public void addRuleInstances(Digester digester)
{
  super.addRuleInstances(digester);

  digester.addFactoryCreate("rss/channel/cloud", getCloudFactory());
  digester.addSetNext("rss/channel/cloud", "setCloud");
  digester.addCallMethod("rss/channel/cloud", 
                         "setDomain",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/cloud",
                        0,
                        "domain");
  digester.addCallMethod("rss/channel/cloud",
                         "setPort",
                         1,
                         new Class[] { Integer.TYPE });
  digester.addCallParam("rss/channel/cloud",
                        0,
                        "port");
  digester.addCallMethod("rss/channel/cloud",
                         "setPath",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/cloud",
                        0,
                        "path");
  digester.addCallMethod("rss/channel/cloud",
                         "setRegisterProcedure",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/cloud",
                        0,
                        "registerProcedure");
  digester.addCallMethod("rss/channel/cloud",
                         "setProtocol",
                         1,
                         new Class[] { CloudProtocol.class });
  digester.addCallParam("rss/channel/cloud",
                        0,
                        "protocol");
  digester.addFactoryCreate("rss/channel/item/source", getSourceFactory());
  digester.addSetNext("rss/channel/item/source", "setSource");
  digester.addCallMethod("rss/channel/item/source", 
                         "setUrl",
                         1,
                         new Class[] { URL.class });
  digester.addCallParam("rss/channel/item/source",
                        0,
                        "url");
  digester.addCallMethod("rss/channel/item/source", 
                         "setName",
                         0,
                         new Class[] { String.class });
  digester.addFactoryCreate("rss/channel/item/enclosure", 
                            getEnclosureFactory());
  digester.addSetNext("rss/channel/item/enclosure", "setEnclosure");
  digester.addCallMethod("rss/channel/item/enclosure", 
                         "setUrl",
                         1,
                         new Class[] { URL.class });
  digester.addCallParam("rss/channel/item/enclosure",
                        0,
                        "url");
  digester.addCallMethod("rss/channel/item/enclosure", 
                         "setLength",
                         1,
                         new Class[] { Integer.TYPE });
  digester.addCallParam("rss/channel/item/enclosure",
                        0,
                        "length");
  digester.addCallMethod("rss/channel/item/enclosure", 
                         "setMimeType",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/item/enclosure",
                        0,
                        "type");
  digester.addFactoryCreate("rss/channel/item/category", 
                            getCategoryFactory());
  digester.addSetNext("rss/channel/item/category", "addCategory");
  digester.addCallMethod("rss/channel/item/category", 
                         "setDomain",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/item/category",
                        0,
                        "domain");
  digester.addCallMethod("rss/channel/item/category", 
                         "setName",
                         0,
                         new Class[] { String.class });
}

protected ObjectCreationFactory getChannelFactory()
{
  return new ChannelFactory_0_92();
}

protected ObjectCreationFactory getCloudFactory()
{
  return new CloudFactory_0_92();
}

protected ObjectCreationFactory getItemFactory()
{
  return new ItemFactory_0_92();
}

protected ObjectCreationFactory getSourceFactory()
{
  return new SourceFactory_0_92();
}

protected ObjectCreationFactory getEnclosureFactory()
{
  return new EnclosureFactory_0_92();
}

protected ObjectCreationFactory getCategoryFactory()
{
  return new CategoryFactory_0_92();
}
}
