package org.jaggregator.rss.rss_2_00;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.jaggregator.rss.Category;
import org.jaggregator.rss.Module;
import org.jaggregator.rss.common.ExtensionSupport;
import org.jaggregator.rss.rss_0_92.ChannelImpl_0_92;
import org.jaggregator.rss.Channel;

/**
 * Canonical implementation of the <code>Channel_2_00</code>
 * interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public class ChannelImpl_2_00
  extends ChannelImpl_0_92
  implements Channel_2_00
{
private Set categorySet;
private String generator;
private int ttl = -1;

private ExtensionSupport extensionSupport;

public ChannelImpl_2_00()
{
  this.categorySet = new HashSet();
  this.extensionSupport = new ExtensionSupport();
}

public Collection getCategories()
{
  return categorySet;
}

public void setCategories(Collection categoryCol)
{
  this.categorySet.clear();
  this.categorySet.addAll(categoryCol);
}

public void addCategory(Category category)
{
  this.categorySet.add(category);
}

public boolean hasCategories()
{
  return (categorySet.size() > 0);
}

public String getGenerator()
{
  return generator;
}

public void setGenerator(String generator)
{
  this.generator = generator;
}

public boolean hasGenerator()
{
  return (generator != null);
}

public int getTtl()
{
  return ttl;
}

public void setTtl(int ttl)
{
  this.ttl = ttl;
}

public boolean hasTtl()
{
  return (ttl >= 0);
}

public Collection getModules()
{
  return extensionSupport.getModules();
}

public Module getModule(String namespace)
{
  return extensionSupport.getModule(namespace);
}

public void addModule(Module module)
{
  extensionSupport.addModule(module);
}

public boolean hasModule(String namespace)
{
  return extensionSupport.hasModule(namespace);
}

public boolean channelLevelEquals(Channel o)
{
  if(this == o)
    return true;
  
  if(o == null)
    return false;

  if(this.getClass() != o.getClass())
    return false;
  
  if(super.channelLevelEquals(o) == false)
    return false;
  
  ChannelImpl_2_00 rhs = (ChannelImpl_2_00) o;

  return new EqualsBuilder()
    .append(categorySet, rhs.categorySet)
    .append(generator, rhs.generator)
    .append(ttl, rhs.ttl)
    .append(extensionSupport, rhs.extensionSupport)
    .isEquals();
}
}
