package org.jaggregator.rss.util;

import java.io.BufferedInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.DateFormat;
import java.util.Date;
import java.text.ParseException;

/**
 * Retrieves a channel from a file. It tries to reduce CPU cycles
 * by checking the time when the file was last modified. It reads
 * the file only if it has changed since the last time.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class ChannelFileRetriever
  extends ChannelRetriever
{
private String fileName;
private DateFormat dateFormat;

public ChannelFileRetriever(String fileName)
{
  this.fileName = fileName;
  dateFormat = DateFormat.getDateTimeInstance();
}

protected byte[] retrieve(Response newResponse)
  throws RetrieveException
{
  Date date = new Date(0);

  if(headerTable.containsKey("If-Modified-Since"))
    {
      String dateString = (String) headerTable.get("If-Modified-Since");
      
      try
        {
          date = dateFormat.parse(dateString);
        }
      catch(ParseException ex)
        {
          //fall through
        }
    }

  File file = new File(fileName);
  byte[] data;

  if(file.lastModified() > date.getTime())
    {
      data = retrieveModifiedChannel(newResponse);
    }
  else
    {
      data = null;
      newResponse.statusCode = 304;
      newResponse.statusText = "Not Modified";
      newResponse.retrieveError = false;
    }

  return data;
}

private byte[] retrieveModifiedChannel(Response newResponse)
  throws RetrieveException
{
  try
    {
      InputStream istream = 
        new BufferedInputStream(
          new FileInputStream(fileName));
  
      ByteArrayOutputStream ostream = new ByteArrayOutputStream(4096);
  
      int b = istream.read();
      do
        {
          ostream.write(b);
          b = istream.read();
        }
      while(b > -1);

      File file = new File(fileName);
      newResponse.lastModifiedString = 
        dateFormat.format(new Date(file.lastModified()));
      newResponse.eTagString = "ignored";
      newResponse.statusCode = 1;
      newResponse.statusText = "OK";
      newResponse.retrieveError = false;
      
      return ostream.toByteArray();
    }
  catch(IOException ex)
    {
      newResponse.statusCode = -1;
      newResponse.statusText = ex.getMessage();
      newResponse.retrieveError = true;
      
      throw new RetrieveException(ex);
    }
}
}
