package org.jaggregator.rss.util;

import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Map;
import org.apache.commons.httpclient.Header;
import org.apache.commons.httpclient.HeaderElement;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpException;
import org.apache.commons.httpclient.HttpMethod;
import org.apache.commons.httpclient.NameValuePair;
import org.apache.commons.httpclient.methods.GetMethod;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;

/**
 * Retrieves a channel via HTTP. It tries to reduce bandwith by
 * using the <code>If-Modified-Since</code> and
 * <code>If-None-Match</code> headers of the HTTP request.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.4 $
 */
public class ChannelHttpRetriever
  extends ChannelRetriever
{
private HttpClient httpClient;
private URL channelUri;

public ChannelHttpRetriever(URL channelUri)
{
  this.channelUri = channelUri;
  this.httpClient = new HttpClient();
}

protected byte[] retrieve(Response newResponse)
  throws RetrieveException
{
  try
    {
      String host = channelUri.getHost();
      int port = channelUri.getPort();
      if(port == -1)
        port = 80;
      
      if(useProxy)
        httpClient.startSession(host,
                                port,
                                proxyHost,
                                proxyPort);
      else
        httpClient.startSession(host,
                                port);
      
      HttpMethod getMethod = createGETMethod();
      httpClient.executeMethod(getMethod);
      
      newResponse.statusCode = getMethod.getStatusCode();
      newResponse.statusText = getMethod.getStatusText();
      
      if(getMethod.getStatusCode() >= 300)
        {
          newResponse.retrieveError = (getMethod.getStatusCode() != 304);
          return null;
        }

      newResponse.retrieveError = false;
      
      byte[] data = getMethod.getResponseBody();
      
      Header lastModifiedHeader = getMethod.getResponseHeader("Last-Modified");
      if(lastModifiedHeader != null)
        {
          HeaderElement lastModifiedValue = lastModifiedHeader.getValues()[0];
          String lastModifiedString = lastModifiedValue.getName();
          
          newResponse.lastModifiedString = lastModifiedString;
        }
      
      Header eTagHeader = getMethod.getResponseHeader("ETag");
      if(eTagHeader != null)
        {
          HeaderElement eTagValue = eTagHeader.getValues()[0];
          String eTagString = eTagValue.getName();
          
          newResponse.eTagString = eTagString;
        }
      
      httpClient.endSession();
      
      return data;
    }
  catch(IOException ex)
    {
      throw new RetrieveException(ex);
    }
  catch(HttpException ex)
    {
      throw new RetrieveException(ex);
    }
}

private HttpMethod createGETMethod()
{
  HttpMethod getMethod = new GetMethod(channelUri.getFile());

  addRequestHeaders(getMethod);
  addQueryString(getMethod);
  
  return getMethod;
}

private void addRequestHeaders(HttpMethod method)
{
  Iterator iter = headerTable.entrySet().iterator();
  while(iter.hasNext())
    {
      Map.Entry entry = (Map.Entry) iter.next();
      method.setRequestHeader((String) entry.getKey(),
                              (String) entry.getValue());
    }
}

private void addQueryString(HttpMethod method)
{
  if(queryStringTable.size() > 0)
    {
      NameValuePair[] pairs = new NameValuePair[queryStringTable.size()];
      
      Iterator iter = queryStringTable.entrySet().iterator();
      int i = 0;
      while(iter.hasNext())
        {
          Map.Entry entry = (Map.Entry) iter.next();
          NameValuePair pair = 
            new NameValuePair((String) entry.getKey(),
                              (String) entry.getValue());
          
          pairs[i++] = pair;
        }
      
      method.setQueryString(pairs);
    }
}
}
