package org.jaggregator.rss.util;

import java.io.IOException;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.Attributes;

/**
 * Given a InputSource of channel data, an instance
 * of this class detects the channels format.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.6 $
 */
public class ChannelVersionDetector
  extends DefaultHandler
{
private Version version;

public Version detectVersion(InputSource channelSource)
  throws RssException
{
  SAXParserFactory factory;
  try
    {
      factory = SAXParserFactory.newInstance();
      factory.setValidating(false);
      factory.setNamespaceAware(true);
      factory.setFeature("http://xml.org/sax/features/namespace-prefixes",
                         true);
      
      SAXParser parser = factory.newSAXParser();
      
      parser.parse(channelSource, this);
    }
  catch(ParserConfigurationException ex)
    {
      throw new RssException("Can't configure SAX parser for detection.");
    }
  catch(IOException ex)
    {
      throw new RssException(ex);
    }
  catch(VersionDetectedException ex)
    {
      //fall through
    }
  catch(UnknownVersionDetectedException ex)
    {
      version = null;
      //fall through
    }
  catch(SAXException ex)
    {
      throw new RssException(ex);
    }
  
  if(version == null)
    throw new UnknownVersionException("Can't detect version.");
  
  return version;
}

public void startElement(String namespaceUri,
                         String localName,
                         String qName,
                         Attributes atts)
  throws SAXException
{
  if(namespaceUri.equals("http://www.w3.org/1999/02/22-rdf-syntax-ns#") &&
     localName.equals("RDF"))
    {
      String xmlns = atts.getValue("xmlns");
      
      if(xmlns.equals("http://my.netscape.com/rdf/simple/0.9/"))
        version = Version.VERSION_0_90;
      else if(xmlns.equals("http://purl.org/rss/1.0/"))
        version = Version.VERSION_1_00;

      throw new VersionDetectedException(version);
    }
  else if(localName.equals("rss"))
    {
      String versionString = atts.getValue("version");
      
      version = Version.getEnum(versionString);

      if(version == null)
        throw new UnknownVersionDetectedException(versionString);
      
      throw new VersionDetectedException(version);
    }
}

private class VersionDetectedException
  extends SAXException
{
public VersionDetectedException(Version version)
{
  super("Detected: " + version.toString());
}
}

private class UnknownVersionDetectedException
  extends SAXException
{
public UnknownVersionDetectedException(String versionString)
{
  super("Detected unknown version: " + versionString);
}
}
}
