package org.jaggregator.rss.util;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.HashMap;
import org.jaggregator.rss.ChannelExporter;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.exporter.ExporterImpl_0_90;
import org.jaggregator.rss.exporter.ExporterImpl_0_91;
import org.jaggregator.rss.exporter.ExporterImpl_0_92;
import org.jaggregator.rss.exporter.ExporterImpl_1_00;
import org.jaggregator.rss.exporter.ExporterImpl_2_00;

/**
 * Factory for exporter implementations.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class ExporterFactory
{
private static ExporterFactory instance;

protected ExporterFactory()
{}

public ChannelExporter newExporter(Version version, File outputFile)
  throws RssException, FileNotFoundException
{
  ChannelExporter exporter = null;
  
  if(version.equals(Version.VERSION_0_90))
    exporter = new ExporterImpl_0_90(outputFile);
  else if(version.equals(Version.VERSION_0_91))
    exporter = new ExporterImpl_0_91(outputFile);
  else if(version.equals(Version.VERSION_0_92))
    exporter = new ExporterImpl_0_92(outputFile);
  else if(version.equals(Version.VERSION_1_00))
    exporter = new ExporterImpl_1_00(outputFile);
  else if(version.equals(Version.VERSION_2_00))
    exporter = new ExporterImpl_2_00(outputFile);
  else
    throw new RssException("Unknown version: " + version.getName());
  
  return exporter;
}

public static synchronized ExporterFactory getInstance()
{
  if(instance == null)
    instance = new ExporterFactory();
  
  return instance;
}
}
