package org.jaggregator.util;

import java.net.URL;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Category;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.modules.ContentModule;
import org.jaggregator.rss.rss_1_00.Item_1_00;
import org.jaggregator.rss.rss_2_00.Item_2_00;

/**
 * Utility class that helps with Items. It removes dangerous HTML code from
 *  escription and title. Furthermore, if the item has a
 * code>content:encoded</code> section, <code>ItemUtil</code> will take as
 * description. If not, it defaults to the plain <code>description</code> tag.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.4 $
 */
public class ItemUtil
{
private Category log = Category.getInstance(ItemUtil.class);

public ItemUtil()
{}

public boolean hasDescription(Item item)
{
  if(item instanceof Item_2_00)
    return hasDescription((Item_2_00) item);

  if(item instanceof Item_1_00)
    return hasDescription((Item_1_00) item);

  return item.hasDescription();
}

private boolean hasDescription(Item_1_00 item)
{
  if(item.hasModule(ContentModule.NAMESPACE))
    return true;

  return item.hasDescription();
}

private boolean hasDescription(Item_2_00 item)
{
  if(item.hasModule(ContentModule.NAMESPACE))
    return true;

  return item.hasDescription();
}

public String getDescription(Item item)
{
  String description = null;

  if(item instanceof Item_2_00)
    description = getDescription((Item_2_00) item);
  else if(item instanceof Item_1_00)
    description = getDescription((Item_1_00) item);

  if(description == null)
    description = item.getDescription();

  return filter(description);
}

private String getDescription(Item_1_00 item)
{
  String description;
  if(item.hasModule(ContentModule.NAMESPACE))
    description =
      ((ContentModule) item.getModule(ContentModule.NAMESPACE)).getContent();
  else
    description = item.getDescription();

  return filter(description);
}

private String getDescription(Item_2_00 item)
{
  String description;
  if(item.hasModule(ContentModule.NAMESPACE))
    description =
      ((ContentModule) item.getModule(ContentModule.NAMESPACE)).getContent();
  else
    description = item.getDescription();

  return filter(description);
}

public String filter(String text)
{
  String ret = null;

  try
    {
      if(text != null)
        ret = HtmlFilter.filter(StringUtils.replace(text, "&", "&amp;"));
    }
  catch(Exception ex)
    {
      log.error("caught exception: " + ex.getMessage());
      log.debug("text causing the exception: " + text);
      log.debug(ExceptionUtils.getStackTrace(ex));
    }

  return ret;
}

public String getTitle(Item item)
{
  return filter(item.getTitle());
}

public String createAHrefStartTag(String href)
{
  String ret = HtmlFilter.createAHrefStartTag(href);

  return ret;
}

public String createAHrefStartTag(URL url)
{
  return createAHrefStartTag(url.toExternalForm());
}

public String createPlainAHrefStartTag(String href)
{
  return HtmlFilter.createPlainAHrefStartTag(href);
}

public String createPlainAHrefStartTag(URL url)
{
  return createPlainAHrefStartTag(url.toExternalForm());
}
}
