package org.jaggregator.config;

import java.io.File;
import java.net.URL;
import java.util.Collection;
import java.util.Iterator;
import org.apache.log4j.Category;
import org.jaggregator.TestCase;

/**
 * Unit Test for class ConfigurationParser.java
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.12 $
 */
public class TestConfigurationParser
  extends TestCase 
{
private Category log =
  Category.getInstance(TestConfigurationParser.class);

private ConfigurationParser parser;

public TestConfigurationParser(String name)
{
  super(name);
}

protected void setUp()
{
  parser = new ConfigurationParser(
    createFile(
	   "src/test/org/jaggregator/config/testconfiguration.xml"));
}

public void testParser()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  assertNotNull(configuration);
}

public void testSkinDirectory()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  File actualValue = configuration.getSkinDirectory();
  File expectedValue = new File("skins/default");
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptionsDirectory()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  File actualValue = configuration.getSubscriptionsDirectory();
  File expectedValue = new File("subscriptions");
  
  assertEquals(expectedValue, actualValue);
}

public void testOutputDirectory()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  File actualValue = configuration.getOutputDirectory();
  File expectedValue = new File("output");
  
  assertEquals(expectedValue, actualValue);
}

public void testRefreshRate()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  long actualValue = configuration.getRefreshRate();
  long expectedValue = 3L * 60L * 60L * 1000L;
  
  assertEquals(expectedValue, actualValue);
}

public void testWebLogUrl()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  String actualValue = configuration.getWebLogUrl();
  String expectedValue = "http://www.janek.org/blog";
  
  assertEquals(expectedValue, actualValue);
}

public void testProxyHost()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  String actualValue = configuration.getProxyHost();
  String expectedValue = "192.169.1.10";
  
  assertEquals(expectedValue, actualValue);
}

public void testProxyPort()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  int actualValue = configuration.getProxyPort();
  int expectedValue = 8080;
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptionList()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  Collection actualValue = configuration.getSubscriptionLists();
  
  log.debug(actualValue);
  
  assertNotNull(actualValue);
}

public void testSubscriptionListSize()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  int actualValue = configuration.getSubscriptionLists().size();
  int expectedValue = 2;
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptionListOrder()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  Collection subscriptionLists = configuration.getSubscriptionLists();
  Iterator iter = subscriptionLists.iterator();
  
  {
    String actualValue = ((SubscriptionListDecl) iter.next()).getId();
    String expectedValue = "all-subscriptions";
  
    assertEquals(expectedValue, actualValue);
  }

  {
    String actualValue = ((SubscriptionListDecl) iter.next()).getId();
    String expectedValue = "News";
  
    assertEquals(expectedValue, actualValue);
  }
}

public void testSubscriptionListId()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  SubscriptionListDecl actualValue = 
    configuration.getSubscriptionList("all-subscriptions");
  
  assertNotNull(actualValue);
}

public void testSubscriptionOrderInList()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  SubscriptionListDecl list = 
    configuration.getSubscriptionList("all-subscriptions");

  Iterator iter = list.values().iterator();

  {
    SubscriptionDecl decl = (SubscriptionDecl) iter.next();
  
    String actualValue = decl.getChannelUri().toExternalForm();
    String expectedValue = "http://freshmeat.net/backend/fm.rdf";
  
    assertEquals(expectedValue, actualValue);
  }

  {
    SubscriptionDecl decl = (SubscriptionDecl) iter.next();
  
    String actualValue = decl.getChannelUri().toExternalForm();
    String expectedValue = "http://www.xmlhack.com/rsscat.php";
  
    assertEquals(expectedValue, actualValue);
  }
}

public void testSubscription()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  SubscriptionListDecl list = 
    configuration.getSubscriptionList("all-subscriptions");
  
  int actualValue = list.values().size();
  int expectedValue = 2;
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptionUri()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  SubscriptionListDecl list = 
    configuration.getSubscriptionList("all-subscriptions");
  
  SubscriptionDecl actualValue
    = list.get(new URL("http://freshmeat.net/backend/fm.rdf"));
  
  assertNotNull(actualValue);
}

public void testSubscriptionAltName()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  SubscriptionListDecl list = 
    configuration.getSubscriptionList("all-subscriptions");
  
  SubscriptionDecl decl
    = list.get(new URL("http://freshmeat.net/backend/fm.rdf"));
  
  String actualValue = decl.getAltName();
  String expectedValue = "fm.net";
  
  assertEquals(expectedValue, actualValue);
}

public void testTemplates()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  int actualValue = configuration.getTemplates().size();
  int expectedValue = 2;
  
  assertEquals(expectedValue, actualValue);
}

public void testTemplateFileName()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  TemplateDecl decl = 
    (TemplateDecl) configuration.getTemplates().iterator().next();

  String actualValue = decl.getFileName();
  String expectedValue = "templates/default.vm";
  
  assertEquals(expectedValue, actualValue);
}

public void testTemplateInvokeModeClass()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  TemplateDecl decl = 
    (TemplateDecl) configuration.getTemplates().iterator().next();

  String actualValue = decl.getInvokeModeClassName();
  String expectedValue = "org.jaggregator.generator.AllListsInvoker";
  
  assertEquals(expectedValue, actualValue);
}

public void testTemplateInvokeMode()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  Iterator iter = configuration.getTemplates().iterator();
  iter.next();
  
  TemplateDecl decl = 
    (TemplateDecl) iter.next();

  String actualValue = decl.getInvokeModeClassName();
  String expectedValue = "java.lang.Object";
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptionListRef()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  TemplateDecl templateDecl = 
    (TemplateDecl) configuration.getTemplates().iterator().next();

  log.debug(templateDecl.getFileName());
  
  int actualValue = templateDecl.getSubscriptionListRefs().size();
  int expectedValue = 2;
  
  assertEquals(expectedValue, actualValue);
}

public void testTemplateViewClass()
  throws Exception
{
  Configuration configuration = parser.parse();
  
  Iterator iter = configuration.getTemplates().iterator();
  
  TemplateDecl decl = 
    (TemplateDecl) iter.next();

  String actualValue = decl.getViewClassName();
  String expectedValue = "org.jaggregator.generator.TodayView";
  
  assertEquals(expectedValue, actualValue);
}
}
