package org.jaggregator.rss.common;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import org.apache.log4j.Category;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.rss_0_91.Channel_0_91;
import org.jaggregator.rss.rss_0_91.Parser_0_91;
import org.xml.sax.InputSource;

/**
 * Unit Test for class TestSubscriptionImpl.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class TestSubscriptionImpl
  extends TestCase
{
private Category log = Category.getInstance(TestSubscriptionImpl.class);
private SubscriptionImpl subscription;

public TestSubscriptionImpl(String name)
{
  super(name);
}

public void setUp()
{
  this.subscription = new SubscriptionImpl();
}

public void testLastRetrievedDate()
{
  Date expectedValue = new Date(0);
  subscription.setLastRetrievedDate(expectedValue);
  Date actualValue = subscription.getLastRetrievedDate();

  assertEquals(expectedValue, actualValue);
}

public void testSetChannel()
  throws Exception
{
  Parser parser = new Parser_0_91();
  
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(0);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);
  
  assertNotNull(subscription.getChannel());
  
  assertEquals(1, subscription.dateItemMap.size());
  ArrayList itemList = 
    (ArrayList) subscription.dateItemMap.get(lastRetrievedDate);
  assertEquals(4, itemList.size());
  
  Item item = 
    (Item)channel.getItems().get(0);
  assertTrue((itemList.indexOf(item) >= 0));
}

public void testUpdateChannelNoNewItems()
  throws Exception
{
  testSetChannel();
  
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);

  Date lastRetrievedDate = new Date(0);

  ArrayList itemList = 
    (ArrayList) subscription.dateItemMap.get(lastRetrievedDate);
  assertEquals(4, itemList.size());
}

public void testUpdateChannelAllNewItems()
  throws Exception
{
  testSetChannel();
  
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  subscription.updateChannel(channel);

  assertEquals(2, subscription.dateItemMap.size());

  Date firstRetrievedDate = new Date(0);
  ArrayList firstList = 
    (ArrayList) subscription.dateItemMap.get(firstRetrievedDate);
  assertEquals(4, firstList.size());

  Date lastRetrievedDate = subscription.getLastRetrievedDate();
  ArrayList secondList = 
    (ArrayList) subscription.dateItemMap.get(lastRetrievedDate);
  assertEquals(6, secondList.size());
}

public void testUpdateChannelSomeNewItems()
  throws Exception
{
  testSetChannel();
  
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  channel.getItems().remove(0);
  channel.getItems().remove(1);
  subscription.updateChannel(channel);

  assertEquals(2, subscription.dateItemMap.size());

  Date firstRetrievedDate = new Date(0);
  ArrayList firstList = 
    (ArrayList) subscription.dateItemMap.get(firstRetrievedDate);
  assertEquals(4, firstList.size());

  Date lastRetrievedDate = subscription.getLastRetrievedDate();
  ArrayList secondList = 
    (ArrayList) subscription.dateItemMap.get(lastRetrievedDate);
  assertEquals(4, secondList.size());
}

public void testHasChangedSince1()
{
  Date lastRetrievedDate = new Date();

  subscription.setLastRetrievedDate(lastRetrievedDate);
  
  Date earlier = new Date(lastRetrievedDate.getTime() - 10000);

  assertTrue(subscription.hasChangedSince(earlier));
}

public void testHasChangedSince2()
{
  Date lastRetrievedDate = new Date();

  subscription.setLastRetrievedDate(lastRetrievedDate);
  
  Date later =  new Date(lastRetrievedDate.getTime() + 10000);

  assertFalse(subscription.hasChangedSince(later));
}

public void testHasChangedSince3()
{
  Date lastRetrievedDate = new Date();

  subscription.setLastRetrievedDate(lastRetrievedDate);
  
  assertFalse(subscription.hasChangedSince(lastRetrievedDate));
}

public void testHasNewItems1()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);
  assertTrue(subscription.hasNewItems());
}

public void testHasNewItems2()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);
  assertTrue(subscription.hasNewItems());

  Thread.currentThread().sleep(1000);
  
  subscription.updateChannel(channel);
  assertFalse(subscription.hasNewItems());
}

public void testHasNewItems3()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);
  assertTrue(subscription.hasNewItems());

  Parser parser2 = new Parser_0_91();
  Channel channel2 = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));

  subscription.updateChannel(channel2);
  assertTrue(subscription.hasNewItems());
}

public void testGetNewItems1()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);

  List actualValue = subscription.getNewItems();
  List expectedValue = channel.getItems();
  
  assertEquals(expectedValue, actualValue);
}

public void testGetNewItems2()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
  
  subscription.updateChannel(channel);

  List actualValue = subscription.getNewItems();
  List expectedValue = channel.getItems();
  
  assertEquals(expectedValue, actualValue);

  Parser parser2 = new Parser_0_91();
  Channel channel2 = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  channel2.getItems().remove(0);
  channel2.getItems().remove(1);
  subscription.updateChannel(channel2);

  List actualValue2 = subscription.getNewItems();
  List expectedValue2 = new ArrayList(channel2.getItems());
  
  assertEquals(expectedValue2, actualValue2);
}

public void testGetItems1()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  List actualValue = subscription.getItems(lastRetrievedDate);
  List expectedValue = channel.getItems();
  
  assertEquals(expectedValue, actualValue);
}

public void testGetItems2()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  List actualValue = subscription.getItems(new Date(0));
  List expectedValue = channel.getItems();
  
  assertEquals(expectedValue, actualValue);
}

public void testGetItems3()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  List actualValue = subscription.getItems(new Date(100000 + 10000));
  List expectedValue = new ArrayList();
  
  assertEquals(expectedValue, actualValue);
}

public void testGetItems4()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  Parser parser2 = new Parser_0_91();
  Channel channel2 = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  channel2.getItems().remove(0);
  channel2.getItems().remove(1);
  List expectedValue2 = new ArrayList(channel.getItems());
  expectedValue2.addAll(channel2.getItems());

  subscription.updateChannel(channel2);
  
  List actualValue2 = subscription.getItems(new Date(0));

  log.debug("\n\nexpectedValue2:");
  logItemList(expectedValue2);
  
  log.debug("\n\nactualValue2:");
  logItemList(actualValue2);
  
  assertEquals(expectedValue2.size(), actualValue2.size());
  assertEquals(expectedValue2, actualValue2);
}

private void logItemList(List list)
{
  log.debug("logItemList - begin");
  
  Iterator iter = list.iterator();
  while(iter.hasNext())
    {
      Item item = (Item) iter.next();
      log.debug("item: " + item.getTitle());
      log.debug("item.hash: " + item.calculateUniqueId());
    }
  
  log.debug("logItemList - end");
}

public void testGetItems5()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  Parser parser2 = new Parser_0_91();
  Channel channel2 = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  List expectedValue2 = new ArrayList(channel.getItems());
  expectedValue2.addAll(0, channel2.getItems());

  subscription.updateChannel(channel2);
  
  List actualValue2 = subscription.getChannel().getItems();

  log.debug("\n\nexpectedValue2:");
  logItemList(expectedValue2);
  
  log.debug("\n\nactualValue2:");
  logItemList(actualValue2);
  
  assertEquals(expectedValue2.size(), actualValue2.size());
  assertEquals(expectedValue2, actualValue2);
}
  
public void testHasChannelLevelChanges()
  throws Exception
{
  Parser parser = new Parser_0_91();
  Channel channel = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));

  Date lastRetrievedDate = new Date(100000);
  subscription.setLastRetrievedDate(lastRetrievedDate);
  subscription.setChannel(channel);

  subscription.updateChannel(channel);
  
  assertFalse(subscription.hasChannelLevelChanges());
  
  Parser parser2 = new Parser_0_91();
  Channel channel2 = (Channel_0_91) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml"));
  
  subscription.updateChannel(channel2);

  assertTrue(subscription.hasChannelLevelChanges());
  assertTrue(channel2.channelLevelEquals(subscription.getChannel()));
}
}
