package org.jaggregator.rss.modules;

import java.net.URL;
import java.util.Collection;
import org.jaggregator.TestCase;
import org.jaggregator.rss.*;
import org.jaggregator.rss.rss_2_00.Channel_2_00;
import org.jaggregator.rss.rss_2_00.Parser_2_00;
import org.xml.sax.InputSource;

/**
 * Unit Test for class BlogChannelModule.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestBlogChannelModule 
  extends TestCase 
{
private Channel_2_00 channel;
private BlogChannelModuleImpl_2_00 blogChannelModule;

public TestBlogChannelModule(String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_2_00();
  
  channel = (Channel_2_00) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_2_00/rss-example-2.0.xml"));

  blogChannelModule = 
    (BlogChannelModuleImpl_2_00) channel.getModule(
      BlogChannelModuleRuleSet_2_00.NAMESPACE);
}

public void testParse()
{
  assertNotNull(channel);
}

public void testInitialized()
{
  boolean actualValue = blogChannelModule.isInitialized();
  boolean expectedValue = true;
  
  assertEquals(expectedValue, actualValue);
}

public void testBlogChannelModule()
{
  assertNotNull(blogChannelModule);
}

public void testBlogRoll()
  throws Exception
{
  URL actualValue = blogChannelModule.getBlogRoll();
  URL expectedValue = new URL("http://radio.weblogs.com/0001015/userland/scriptingNewsLeftLinks.opml");
  
  assertEquals(expectedValue, actualValue);
}

public void testSubscriptions()
  throws Exception
{
  URL actualValue = blogChannelModule.getSubscriptions();
  URL expectedValue = new URL("http://radio.weblogs.com/0001015/gems/mySubscriptions.opml");
  
  assertEquals(expectedValue, actualValue);
}

public void testBlink()
  throws Exception
{
  URL actualValue = blogChannelModule.getBlink();
  URL expectedValue = new URL("http://diveintomark.org/");
  
  assertEquals(expectedValue, actualValue);
}

public void testChanges()
  throws Exception
{
  URL actualValue = blogChannelModule.getChanges();
  URL expectedValue = new URL("http://www.janek.org/changes.xml");
  
  assertEquals(expectedValue, actualValue);
}

public void testChannelWOBlogChannelModule()
  throws Exception
{
  Parser parser = new Parser_2_00();
  
  Channel_2_00 channel = (Channel_2_00) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_92/rss-example-0.92.xml"));

  Object actualValue = channel.getModule(
    BlogChannelModuleRuleSet_2_00.NAMESPACE);

  assertNull(actualValue);
}
}
