package org.jaggregator.rss.modules;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.FileInputStream;
import java.io.StringReader;
import java.net.URL;
import java.util.Collection;
import javax.xml.parsers.DocumentBuilderFactory;
import junit.framework.Test;
import junit.framework.TestCase;
import org.custommonkey.xmlunit.DetailedDiff;
import org.custommonkey.xmlunit.Diff;
import org.jaggregator.rss.*;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelExporter;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.exporter.ExporterImpl_1_00;
import org.jaggregator.rss.rss_1_00.Channel_1_00;
import org.jaggregator.rss.rss_1_00.Item_1_00;
import org.jaggregator.rss.rss_1_00.Parser_1_00;
import org.jaggregator.util.XMLTestCase;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;

/**
 * Unit Test for class TestContentModuleFragmentExporter
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestContentModuleFragmentExporterRss_1_00
  extends XMLTestCase
{
public TestContentModuleFragmentExporterRss_1_00(String name)
{
  super(name);
}

public void testParse()
  throws Exception
{
  Parser parser = new Parser_1_00();

  Channel_1_00 channel = (Channel_1_00) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/modules/content-encoded_1_00.xml"));

  assertNotNull(channel);
}

public void testExport()
  throws Exception
{
  Parser parser = new Parser_1_00();

  Channel channel = (Channel) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/modules/content-encoded_1_00.xml"));

  ByteArrayOutputStream ostream = new ByteArrayOutputStream();

  ChannelExporter exporter = new ExporterImpl_1_00(ostream);
  exporter.export(channel);

  System.err.println(ostream.toString());

  InputSource actualSource =
    new InputSource(new ByteArrayInputStream(ostream.toByteArray()));
  Document actualDocument = createDocument(actualSource);

  InputSource expectedSource =
    createInputSourceForFile(
     "src/test/org/jaggregator/rss/modules/" +
     "content-encoded-exported-expected_1_00.xml");
  expectedSource.setEncoding("ISO-8859-1");

  Document expectedDocument = createDocument(expectedSource);

  DetailedDiff detailedDiff = new DetailedDiff(new Diff(expectedDocument,
                                                        actualDocument));

  assertXMLEqual("", detailedDiff, true);
}

public void testNestedCData()
  throws Exception
{
  Parser parser = new Parser_1_00();

  Channel channel = (Channel) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/modules/content-encoded-nested-cdata.xml"));

  ByteArrayOutputStream ostream = new ByteArrayOutputStream();

  ChannelExporter exporter = new ExporterImpl_1_00(ostream);
  exporter.export(channel);

  System.err.println(ostream.toString());

  InputSource actualSource =
    new InputSource(new ByteArrayInputStream(ostream.toByteArray()));
  Document actualDocument = createDocument(actualSource);

  InputSource expectedSource =
    createInputSourceForFile(
     "src/test/org/jaggregator/rss/modules/" +
     "content-encoded-nested-cdata-expected.xml");
  expectedSource.setEncoding("ISO-8859-1");

  Document expectedDocument = createDocument(expectedSource);

  DetailedDiff detailedDiff = new DetailedDiff(new Diff(expectedDocument,
                                                        actualDocument));

  assertXMLEqual("", detailedDiff, true);
}

protected DocumentBuilderFactory createDocumentBuilderFactory()
{
  DocumentBuilderFactory docBuilderFactory =
    super.createDocumentBuilderFactory();

  docBuilderFactory.setNamespaceAware(true);

  return docBuilderFactory;
}
}
