package org.jaggregator.rss.rss_0_92;

import java.net.URL;
import java.util.Collection;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Category;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.CloudProtocol;
import org.jaggregator.rss.Enclosure;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.Source;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;

/**
 * Unit Test for class Parser_0_92.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestParser_0_92 
  extends TestCase 
{
private Channel_0_92 channel;

public TestParser_0_92 (String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_0_92();
  
  channel = (Channel_0_92) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_92/rss-example-0.92.xml"));
}

public void testParse()
{
  assertNotNull(channel);
}

public void testVersion()
{
  Version actualValue = channel.getVersion();
  Version expectedValue = Version.VERSION_0_92;
  assertEquals(expectedValue, actualValue);
}

public void testCloudDomain()
  throws Exception
{
  String actualValue = channel.getCloud().getDomain();
  String expectedValue = "data.ourfavoritesongs.com";
  
  assertEquals(actualValue, expectedValue);
}

public void testCloudPort()
{
  int actualValue = channel.getCloud().getPort();
  int expectedValue = 80;
  
  assertEquals(expectedValue, actualValue);
}

public void testCloudPath()
{
  String actualValue = channel.getCloud().getPath();
  String expectedValue = "/RPC2";
  
  assertEquals(expectedValue, actualValue);
}

public void testCloudRegisterProcedure()
{
  String actualValue = channel.getCloud().getRegisterProcedure();
  String expectedValue = "ourFavoriteSongs.rssPleaseNotify";
  
  assertEquals(expectedValue, actualValue);
}

public void testCloudProtocol()
{
  CloudProtocol actualValue = channel.getCloud().getProtocol();
  CloudProtocol expectedValue = CloudProtocol.XML_RPC;
  
  assertEquals(expectedValue, actualValue);
}

public void testSource()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(1);
  Source source = item.getSource();
  
  assertNotNull(source);
}

public void testSourceUrl()
  throws Exception
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(1);
  Source source = item.getSource();
  
  URL actualValue = source.getUrl();
  URL expectedValue = 
    new URL("http://scriptingnews.userland.com/xml/scriptingNews2.xml");
  
  assertEquals(expectedValue, actualValue);
}

public void testSourceName()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(1);
  Source source = item.getSource();

  String actualValue = source.getName();
  String expectedValue = "Scripting News";
  
  assertEquals(expectedValue, actualValue);
}

public void testEnclosure()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Enclosure enclosure = item.getEnclosure();
  
  assertNotNull(enclosure);
}

public void testEnclosureUrl()
  throws Exception
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Enclosure enclosure = item.getEnclosure();

  URL actualValue = enclosure.getUrl();
  URL expectedValue = new URL("http://www.scripting.com/mp3s/weatherReportDicksPicsVol7.mp3");
  
  assertEquals(expectedValue, actualValue);
}

public void testEnclosureLength()
  throws Exception
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Enclosure enclosure = item.getEnclosure();

  int actualValue = enclosure.getLength();
  int expectedValue = 6182912;
  
  assertEquals(expectedValue, actualValue);
}

public void testEnclosureType()
  throws Exception
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Enclosure enclosure = item.getEnclosure();

  String actualValue = enclosure.getMimeType();
  String expectedValue = "audio/mpeg";
  
  assertEquals(expectedValue, actualValue);
}

public void testCategory()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Collection categories = item.getCategories();
  
  assertNotNull(categories);
}

public void testCategoryDomain()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Category category = (Category) item.getCategories().iterator().next();
  
  String actualValue = category.getDomain();
  String expectedValue = "http://www.superopendirectory.com/";
  
  assertEquals(expectedValue, actualValue);
}

public void testCategoryName()
{
  Item_0_92 item = (Item_0_92) channel.getItems().get(0);
  Category category = (Category) item.getCategories().iterator().next();
  
  String actualValue = category.getName();
  String expectedValue = "standards/xsl/implementations";
  
  assertEquals(expectedValue, actualValue);
}

public void testItemChannelRelationship()
{
  Item item = (Item) channel.getItems().get(0);
  Channel actualValue = item.getChannel();
  Channel expectedValue = channel;
  
  assertEquals(expectedValue, actualValue);
}
}
