package org.jaggregator.rss.rss_1_00;

import java.net.URL;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Category;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelImage;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.TextInput;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.common.ItemImpl;
import org.xml.sax.InputSource;

/**
 * Unit Test for class Parser_1_00.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestParser_1_00 
  extends TestCase 
{
private static final Category log;
private Channel_1_00 channel;

static
{
  BasicConfigurator.configure();
  log = Category.getInstance(TestParser_1_00.class);
}

public TestParser_1_00 (String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_1_00();
  
  channel = (Channel_1_00) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_1_00/rss-example-1.0-core.xml"));
}

public void testParse()
{
  assertNotNull(channel);
}

public void testVersion()
{
  Version actualValue = channel.getVersion();
  Version expectedValue = Version.VERSION_1_00;
  assertEquals(expectedValue, actualValue);
}

public void testChannelAbout()
{
  String actualValue = channel.getAbout();
  String expectedValue = "http://www.xml.com/xml/news.rss";
  
  assertEquals(expectedValue, actualValue);
}

public void testTitle()
{
  String actualValue = channel.getTitle();
  String expectedValue = "XML.com";
  
  assertEquals(expectedValue, actualValue);
}

public void testLink()
  throws Exception
{
  URL actualLink = channel.getLink();
  URL expectedLink = new URL("http://xml.com/pub");
  
  assertEquals(expectedLink, actualLink);
}

public void testDescription()
{
  String actualValue = channel.getDescription();
  String expectedValue = "XML.com features a rich mix of information and services for the XML community.";
  
  assertEquals(expectedValue, actualValue);
}

public void testImage()
{
  ChannelImage actualValue = channel.getImage();
  
  assertNotNull(actualValue);
}

public void testChannelImageAbout()
{
  ChannelImage_1_00 image = (ChannelImage_1_00) channel.getImage();
  String actualValue = image.getAbout();
  String expectedValue = "http://xml.com/universal/images/xml_tiny.gif";
  
  assertEquals(expectedValue, actualValue);
}

public void testImageTitle()
{
  String actualValue = channel.getImage().getTitle();
  String expectedValue = "XML.com";
  
  assertEquals(expectedValue, actualValue);
}

public void testImageUrl()
  throws Exception
{
  URL actualValue = channel.getImage().getUrl();
  URL expectedValue = new URL("http://xml.com/universal/images/xml_tiny.gif");
  
  assertEquals(expectedValue, actualValue);
}

public void testImageLink()
  throws Exception
{
  URL actualValue = channel.getImage().getLink();
  URL expectedValue = new URL("http://www.xml.com");
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInput()
{
  TextInput actualValue = channel.getTextInput();
  
  assertNotNull(actualValue);
}

public void testTextInputAbout()
{
  TextInput_1_00 textInput = (TextInput_1_00) channel.getTextInput();

  String actualValue = textInput.getAbout();
  String expectedValue = "http://search.xml.com";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputTitle()
{
  String actualValue = channel.getTextInput().getTitle();
  String expectedValue = "Search XML.com";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputLink()
  throws Exception
{
  URL actualValue = channel.getTextInput().getLink();
  URL expectedValue = new URL("http://search.xml.com");
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputDescription()
{
  String actualValue = channel.getTextInput().getDescription();
  String expectedValue = "Search XML.com's XML collection";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputName()
{
  String actualValue = channel.getTextInput().getName();
  String expectedValue = "s";
  
  assertEquals(expectedValue, actualValue);
}

public void testItems()
{
  List actualValue = channel.getItems();
  
  assertNotNull(actualValue);
  assertEquals(2, actualValue.size());
}

public void testItemChannelRelationship()
{
  Item item = (Item) channel.getItems().get(0);
  Channel actualValue = item.getChannel();
  Channel expectedValue = channel;
  
  assertEquals(expectedValue, actualValue);
}

public void testItemAbout()
{
  List items = channel.getItems();
  
  String actualValue = ((Item_1_00)items.get(0)).getAbout();
  String expectedValue = "http://xml.com/pub/2000/08/09/xslt/xslt.html";
  
  assertEquals(expectedValue, actualValue);
}

public void testItemsContent()
  throws Exception
{
  List actualValue = channel.getItems();
  List expectedValue = new LinkedList();
  expectedValue.add(
    new ItemImpl("Processing Inclusions with XSLT", 
                 new URL("http://xml.com/pub/2000/08/09/xslt/xslt.html"),
                 "Processing document inclusions with general XML tools can be      problematic. This article proposes a way of preserving inclusion information through SAX-based processing."));
  expectedValue.add(
    new ItemImpl("Putting RDF to Work", 
                 new URL("http://xml.com/pub/2000/08/09/rdfdb/index.html"),
                 "Tool and API support for the Resource Description Framework is slowly coming of age. Edd Dumbill takes a look at RDFDB, one of the most exciting new RDF toolkits."));
  
  assertEquals(expectedValue, actualValue);
}
}
