package org.jaggregator.rss.rss_2_00;

import java.net.URL;
import java.util.Collection;
import java.util.Date;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Category;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;

/**
 * Unit Test for class Parser_2_00
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestParser_2_00 
  extends TestCase 
{
private Channel_2_00 channel;

public TestParser_2_00(String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_2_00();
  
  channel = (Channel_2_00) parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_2_00/rss-example-2.0.xml"));
}

public void testParse()
{
  assertNotNull(channel);
}

public void testVersion()
{
  Version actualValue = channel.getVersion();
  Version expectedValue = Version.VERSION_2_00;
  assertEquals(expectedValue, actualValue);
}

public void testCategory()
{
  Collection categories = channel.getCategories();
  
  assertNotNull(categories);

  int actualValue = categories.size();
  int expectedValue = 1;
  
  assertEquals(expectedValue, actualValue);
}

public void testCategoryDomain()
{
  Category category = (Category) channel.getCategories().iterator().next();
  
  String actualValue = category.getDomain();
  String expectedValue = "Syndic8";
  
  assertEquals(expectedValue, actualValue);
}
public void testCategoryName()
{
  Category category = (Category) channel.getCategories().iterator().next();
  
  String actualValue = category.getName();
  String expectedValue = "1765";
  
  assertEquals(expectedValue, actualValue);
}

public void testGenerator()
{
  String actualValue = channel.getGenerator();
  String expectedValue = "Radio UserLand v8.0.5";
  
  assertEquals(expectedValue, actualValue);
}

public void testTtl()
{
  int actualValue = channel.getTtl();
  int expectedValue = 40;
  
  assertEquals(expectedValue, actualValue);
}

public void testItemAuthor()
{
  Item_2_00 item = (Item_2_00) channel.getItems().get(0);

  String actualValue = item.getAuthor();
  String expectedValue = "Dave Winter";
  
  assertEquals(expectedValue, actualValue);
}

public void testItemComments()
  throws Exception
{
  Item_2_00 item = (Item_2_00) channel.getItems().get(0);

  URL actualValue = item.getComments();
  URL expectedValue = new URL("http://www.janek.org/comments");
  
  assertEquals(expectedValue, actualValue);
}

public void testItemGuid()
{
  Item_2_00 item = (Item_2_00) channel.getItems().get(0);

  String actualValue = item.getGuid().getGuid();
  String expectedValue = "http://scriptingnews.userland.com/backissues/2002/09/29#When:6:56:02PM";
  
  assertEquals(expectedValue, actualValue);
}

public void testItemGuidPermaLink()
{
  Item_2_00 item = (Item_2_00) channel.getItems().get(0);

  boolean actualValue = item.getGuid().isPermaLink();
  boolean expectedValue = true;
  
  assertEquals(expectedValue, actualValue);
}

public void testItemPubDate()
{
  Item_2_00 item = (Item_2_00) channel.getItems().get(0);

  Date actualValue = item.getPubDate();
  Date expectedValue = new Date(1033350962000L);
  
  assertEquals(expectedValue, actualValue);
}
}
