package org.jaggregator.rss.util;

import java.net.URL;
import junit.framework.Test;
import junit.framework.TestCase;
import org.jaggregator.rss.Channel;

/**
 * Unit Test for class TestChannelHttpRetriever.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class TestChannelHttpRetriever
  extends TestCase
{
private Response firstResponse;
private boolean isOnline = true;

public TestChannelHttpRetriever(String name)
{
  super(name);
}

protected void setUp()
{
  String onlineModeString = System.getProperty("online.mode");

  if(onlineModeString.equalsIgnoreCase("false") ||
     onlineModeString.equalsIgnoreCase("off"))
    isOnline = false;
}

public void testRetrieveChannel091ViaHttp()
  throws Exception
{
  if(isOnline == false)
    return;
  
  ChannelRetriever retriever = 
    ChannelRetriever.getRetriever(
      new URL("http://www.janek.org/rss/rss-example-0.91.xml"));
  Response response = retriever.retrieve();
  Channel retrievedChannel = response.getChannel();

  assertNotNull(retrievedChannel);
  
  String actualValue = retrievedChannel.getTitle();
  String expectedValue = "WriteTheWeb";
  
  assertEquals(expectedValue, actualValue);

  firstResponse = response;
}

public void testRetrieveIfModifiedSince()
  throws Exception
{
  if(isOnline == false)
    return;

  testRetrieveChannel091ViaHttp();
  
  ChannelRetriever retriever = 
    ChannelRetriever.getRetriever(
      new URL("http://www.janek.org/rss/rss-example-0.91.xml"));
  Response response = retriever.retrieve(firstResponse.getLastModifiedString(),
                                         firstResponse.getEtagString());

  Channel retrievedChannel = response.getChannel();
  
  assertFalse(response.isRetrieveError());
  assertEquals(304, response.getStatusCode());
  assertNull(response.getChannel());
}
}
