package org.jaggregator.rss.util;

import org.jaggregator.TestCase;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;

/**
 * Unit Test for class TestChannelVersionDetector.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.7 $
 */
public class TestChannelVersionDetector
  extends TestCase
{
private ChannelVersionDetector detector;

public TestChannelVersionDetector(String name)
{
  super(name);
}

protected void setUp()
{
  detector = new ChannelVersionDetector();
}

public void testVersion_0_90()
  throws Exception
{
  InputSource isource =     
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_90/rss-example-0.90.xml");

  Version actualValue = detector.detectVersion(isource);
  Version expectedValue = Version.VERSION_0_90;
  
  assertEquals(expectedValue, actualValue);
}

public void testVersion_0_91()
  throws Exception
{
  InputSource isource =     
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml");

  Version actualValue = detector.detectVersion(isource);
  Version expectedValue = Version.VERSION_0_91;
  
  assertEquals(expectedValue, actualValue);
}

public void testVersion_0_92()
  throws Exception
{
  InputSource isource =     
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_92/rss-example-0.92.xml");

  Version actualValue = detector.detectVersion(isource);
  Version expectedValue = Version.VERSION_0_92;
  
  assertEquals(expectedValue, actualValue);
}

public void testVersion_2_00()
  throws Exception
{
  InputSource isource =     
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_2_00/rss-example-2.0.xml");

  Version actualValue = detector.detectVersion(isource);
  Version expectedValue = Version.VERSION_2_00;
  
  assertEquals(expectedValue, actualValue);
}

public void testVersion_1_00()
  throws Exception
{
  InputSource isource =     
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_1_00/rss-example-1.0-core.xml");

  Version actualValue = detector.detectVersion(isource);
  Version expectedValue = Version.VERSION_1_00;
  
  assertEquals(expectedValue, actualValue);
}

public void testUnknownVersion()
  throws Exception
{
  try
    {
      InputSource isource =     
        createInputSourceForFile(
          "src/test/org/jaggregator/rss/util/rss-unknown-version.xml");

      detector.detectVersion(isource);

      fail("Expected a UnknownVersionException");
    }
  catch(UnknownVersionException ex)
    {
      //if this exception is caught, everything is fine.
    }
}
}
