package org.jaggregator.rss.util;

import java.io.File;
import java.net.URL;
import java.util.List;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Subscription;

/**
 * Unit Test for class TestSubscriptionRegistry.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class TestSubscriptionRegistry
  extends TestCase 
{
private File subscriptionsRoot = 
  createFile("src/test/org/jaggregator/rss/common/subscriptionsroot");

private SubscriptionRegistry registry;

public TestSubscriptionRegistry (String name)
{
  super(name);
}

protected void setUp()
{
  registry = SubscriptionRegistry.getInstance(subscriptionsRoot);

  registry.initialize();
}

protected void tearDown()
{
  List exceptionList = SubscriptionRegistry.shutdown(registry, false);

  if(exceptionList.size() > 0)
    fail("exceptions in tearDown: "+ exceptionList);
}

public void testInitialize()
{
  assertNotNull(registry.getSubscriptions());
}

public void testInitializeNrOfSubscriptions()
{
  assertEquals(1, registry.getSubscriptions().size());
}

public void testInitializeContentOfRegistry()
  throws Exception
{
  Subscription subscription = 
    (Subscription) registry.getSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"));
  
  assertEquals(
    new URL("http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"),
            subscription.getUrl());
}

public void testContainsSubscription()
  throws Exception
{
  assertTrue(
    registry.containsSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml")));

  assertFalse(
    registry.containsSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel")));
}

public void testGetSubscription()
  throws Exception
{
  Subscription s = 
    (Subscription) registry.getSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"));
  
  assertEquals(
    s,
    registry.getSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml")));
}

public void testSubscribe()
  throws Exception
{
  registry.subscribe(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel2.xml"),
      false);
  
  assertEquals(2, registry.getSubscriptions().size());
}

public void testSetGetRepeatInterval()
  throws Exception
{
  URL channelUri = 
    new URL("http://www.jaggregator.org/testbed/subscriptiontestchannel.xml");
  long expectedValue = 1204794592434L;
  
  registry.setRefreshRate(channelUri, expectedValue);
  
  long actualValue = registry.getRefreshRate(channelUri);
  
  assertEquals(expectedValue, actualValue);
}

public void testScheduleRetrieval()
  throws Exception
{
  registry.scheduleRetrieval();
  Thread.currentThread().sleep(3000);
}
}
