package org.jaggregator.util;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.custommonkey.xmlunit.XMLUnit;
import org.jaggregator.TestUtils;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;

/**
 * For some, reason XMLUnit testcases crash when constructing
 * org.w3c.Document instances.&nbsp;This class provides a fix for
 * that.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.3 $
 */
public class XMLTestCase 
  extends org.custommonkey.xmlunit.XMLTestCase
{
public XMLTestCase(String name)
{
  super(name);

  XMLUnit.setIgnoreWhitespace(true);
}

  protected String getBaseDir()
  {
    return TestUtils.getBaseDir();
  }

  protected File createFile(String fileName)
  {
    return TestUtils.createFile(fileName);
  }
  
  protected InputSource createInputSourceForFile(String systemId)
    throws MalformedURLException
  {
    return TestUtils.createInputSourceForFile(systemId);
  }

  public InputStream createInputStreamForFile(String fileName)
    throws IOException
  {
    return TestUtils.createInputStreamForFile(fileName);
  }

  protected DocumentBuilder createDocumentBuilder()
    throws Exception
  {
    DocumentBuilderFactory docBuilderFactory = 
      createDocumentBuilderFactory();
      DocumentBuilder docBuilder =
        docBuilderFactory.newDocumentBuilder();

    return docBuilder;
  }

  protected Document createDocument(InputStream istream)
    throws Exception
  {
    DocumentBuilder builder = createDocumentBuilder();
    return builder.parse(istream);
  }

  protected Document createDocument(InputSource source)
    throws Exception
  {
    DocumentBuilder builder = createDocumentBuilder();
    return builder.parse(source);
  }

  protected DocumentBuilderFactory createDocumentBuilderFactory()
  {
    DocumentBuilderFactory docBuilderFactory = 
      DocumentBuilderFactory.newInstance();
    
    docBuilderFactory.setValidating(false);
    docBuilderFactory.setIgnoringElementContentWhitespace(true);
    
    return docBuilderFactory;
  }
}
